# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import json
import struct

try:
    import lz4
except ImportError:
    lz4 = None
from requests import Response

from volcengine.tls.log_pb2 import LogGroupList
from volcengine.tls.data import *
from volcengine.tls.tls_exception import TLSException


class TLSResponse:
    def __init__(self, response: Response):
        self.headers = response.headers
        self.request_id = response.headers[X_TLS_REQUEST_ID]

        if "json" in self.headers[CONTENT_TYPE]:
            if response.text != "":
                self.response = json.loads(response.text)
            else:
                self.response = {}
        else:
            self.response = {DATA: response.content}

    @staticmethod
    def _get_host_group_hosts_rules_info(host_group_hosts_rules_info) -> HostGroupHostsRulesInfo:
        host_group_hosts_rules_info[HOST_GROUP_INFO] = \
            HostGroupInfo.set_attributes(data=host_group_hosts_rules_info[HOST_GROUP_INFO])
        host_group_info = host_group_hosts_rules_info[HOST_GROUP_INFO]

        host_infos = host_group_hosts_rules_info[HOST_INFOS]
        for i in range(len(host_infos)):
            host_infos[i] = HostInfo.set_attributes(data=host_infos[i])

        rule_infos = host_group_hosts_rules_info[RULE_INFOS]
        for i in range(len(rule_infos)):
            rule_infos[i] = RuleInfo.set_attributes(data=rule_infos[i])

        return HostGroupHostsRulesInfo(host_group_info, host_infos, rule_infos)


class CreateProjectResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CreateProjectResponse, self).__init__(response)

        self.project_id = self.response[PROJECT_ID]


class DeleteProjectResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteProjectResponse, self).__init__(response)


class ModifyProjectResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ModifyProjectResponse, self).__init__(response)


class DescribeProjectResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeProjectResponse, self).__init__(response)

        self.project = ProjectInfo.set_attributes(data=self.response)


class DescribeProjectsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeProjectsResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.projects = self.response[PROJECTS]

        for i in range(len(self.projects)):
            self.projects[i] = ProjectInfo.set_attributes(data=self.projects[i])


class CreateTopicResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CreateTopicResponse, self).__init__(response)

        self.topic_id = self.response[TOPIC_ID]


class DeleteTopicResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteTopicResponse, self).__init__(response)


class ModifyTopicResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ModifyTopicResponse, self).__init__(response)


class DescribeTopicResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeTopicResponse, self).__init__(response)

        self.topic = TopicInfo.set_attributes(data=self.response)


class DescribeTopicsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeTopicsResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.topics = self.response[TOPICS]

        for i in range(len(self.topics)):
            self.topics[i] = TopicInfo.set_attributes(data=self.topics[i])


class CreateIndexResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CreateIndexResponse, self).__init__(response)

        self.topic_id = self.response[TOPIC_ID]


class DeleteIndexResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteIndexResponse, self).__init__(response)


class ModifyIndexResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ModifyIndexResponse, self).__init__(response)


class DescribeIndexResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeIndexResponse, self).__init__(response)

        if self.response[FULL_TEXT] is not None:
            self.full_text = FullTextInfo.set_attributes(data=self.response[FULL_TEXT])
        else:
            self.full_text = None
        self.key_value = self.response[KEY_VALUE]
        self.create_time = self.response[CREATE_TIME]
        self.modify_time = self.response[MODIFY_TIME]

        for i in range(len(self.key_value)):
            self.key_value[i] = KeyValueInfo(key=self.key_value[i][KEY],
                                             value=ValueInfo.set_attributes(data=self.key_value[i][VALUE]))


class PutLogsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(PutLogsResponse, self).__init__(response)


class DescribeCursorResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeCursorResponse, self).__init__(response)

        self.cursor = self.response[CURSOR]


class ConsumeLogsResponse(TLSResponse):
    def __init__(self, response: Response, compression: str):
        super(ConsumeLogsResponse, self).__init__(response)

        self.x_tls_cursor = self.headers[X_TLS_CURSOR]
        self.x_tls_count = int(self.headers[X_TLS_COUNT])
        self.pb_message = None

        if DATA in self.response:
            pb_message = self.response[DATA]
            if compression == LZ4:
                pb_message = lz4.uncompress(struct.pack('<I', int(self.headers[X_TLS_BODYRAWSIZE])) + pb_message)

            self.pb_message = LogGroupList()
            self.pb_message.ParseFromString(pb_message)


class SearchLogsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(SearchLogsResponse, self).__init__(response)

        self.search_result = SearchResult.set_attributes(data=self.response)


class DescribeLogContextResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeLogContextResponse, self).__init__(response)

        self.log_context_infos = self.response[LOG_CONTEXT_INFOS]
        self.prev_over = self.response[PREV_OVER]
        self.next_over = self.response[NEXT_OVER]


class WebTracksResponse(TLSResponse):
    def __init__(self, response: Response):
        super(WebTracksResponse, self).__init__(response)


class DescribeHistogramResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeHistogramResponse, self).__init__(response)

        self.result_status = self.response[RESULT_STATUS]
        self.interval = self.response[INTERVAL]
        self.total_count = self.response[TOTAL_COUNT]
        self.histogram = self.response[HISTOGRAM]

        for i in range(len(self.histogram)):
            self.histogram[i] = HistogramInfo.set_attributes(data=self.histogram[i])


class CreateDownloadTaskResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CreateDownloadTaskResponse, self).__init__(response)

        self.task_id = self.response[TASK_ID]


class DescribeDownloadTasksResponse(TLSResponse):
    def __init__(self, response):
        super(DescribeDownloadTasksResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.tasks = self.response[TASKS]

        for i in range(len(self.tasks)):
            self.tasks[i] = TaskInfo.set_attributes(data=self.tasks[i])


class DescribeDownloadUrlResponse(TLSResponse):
    def __init__(self, response):
        super(DescribeDownloadUrlResponse, self).__init__(response)

        self.download_url = self.response[DOWNLOAD_URL]


class DescribeShardsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeShardsResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.shards = self.response[SHARDS]

        for i in range(len(self.shards)):
            self.shards[i] = QueryResp.set_attributes(data=self.shards[i])


class CreateHostGroupResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CreateHostGroupResponse, self).__init__(response)

        self.host_group_id = self.response[HOST_GROUP_ID]


class DeleteHostGroupResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteHostGroupResponse, self).__init__(response)


class ModifyHostGroupResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ModifyHostGroupResponse, self).__init__(response)


class DescribeHostGroupResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeHostGroupResponse, self).__init__(response)

        self.host_group_hosts_rules_info = \
            DescribeHostGroupResponse._get_host_group_hosts_rules_info(self.response[HOST_GROUP_HOSTS_RULES_INFO])
        self.response[HOST_GROUP_HOSTS_RULES_INFO] = self.host_group_hosts_rules_info


class DescribeHostGroupsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeHostGroupsResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.host_group_hosts_rules_infos = self.response[HOST_GROUP_HOSTS_RULES_INFOS]

        for i in range(len(self.host_group_hosts_rules_infos)):
            self.host_group_hosts_rules_infos[i] = \
                DescribeHostGroupsResponse._get_host_group_hosts_rules_info(self.host_group_hosts_rules_infos[i])


class ModifyHostGroupsAutoUpdateResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ModifyHostGroupsAutoUpdateResponse, self).__init__(response)


class DescribeHostsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeHostsResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.host_infos = self.response[HOST_INFOS]

        for i in range(len(self.host_infos)):
            self.host_infos[i] = HostInfo.set_attributes(data=self.host_infos[i])


class DeleteHostResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteHostResponse, self).__init__(response)


class DescribeHostGroupRulesResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeHostGroupRulesResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.rule_infos = self.response[RULE_INFOS]

        for i in range(len(self.rule_infos)):
            self.rule_infos[i] = RuleInfo.set_attributes(data=self.rule_infos[i])


class CreateRuleResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CreateRuleResponse, self).__init__(response)

        self.rule_id = self.response[RULE_ID]


class DeleteRuleResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteRuleResponse, self).__init__(response)


class ModifyRuleResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ModifyRuleResponse, self).__init__(response)


class DescribeRuleResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeRuleResponse, self).__init__(response)

        self.project_id = self.response[PROJECT_ID]
        self.project_name = self.response[PROJECT_NAME]
        self.rule_info = RuleInfo.set_attributes(data=self.response[RULE_INFO])
        self.response[RULE_INFO] = self.rule_info
        self.host_group_infos = self.response[HOST_GROUP_INFOS]

        for i in range(len(self.host_group_infos)):
            self.host_group_infos[i] = HostGroupInfo.set_attributes(data=self.host_group_infos[i])


class DescribeRulesResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeRulesResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.rule_infos = self.response[RULE_INFOS]

        for i in range(len(self.rule_infos)):
            self.rule_infos[i] = RuleInfo.set_attributes(data=self.rule_infos[i])


class ApplyRuleToHostGroupsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ApplyRuleToHostGroupsResponse, self).__init__(response)


class DeleteRuleFromHostGroupsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteRuleFromHostGroupsResponse, self).__init__(response)


class CreateAlarmNotifyGroupResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CreateAlarmNotifyGroupResponse, self).__init__(response)

        self.alarm_notify_group_id = self.response[ALARM_NOTIFY_GROUP_ID]


class DeleteAlarmNotifyGroupResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteAlarmNotifyGroupResponse, self).__init__(response)


class ModifyAlarmNotifyGroupResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ModifyAlarmNotifyGroupResponse, self).__init__(response)


class DescribeAlarmNotifyGroupsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeAlarmNotifyGroupsResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.alarm_notify_groups = self.response[ALARM_NOTIFY_GROUPS]

        for i in range(len(self.alarm_notify_groups)):
            self.alarm_notify_groups[i] = AlarmNotifyGroupInfo.set_attributes(data=self.alarm_notify_groups[i])


class CreateAlarmResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CreateAlarmResponse, self).__init__(response)

        self.alarm_id = self.response[ALARM_ID]


class DeleteAlarmResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DeleteAlarmResponse, self).__init__(response)


class ModifyAlarmResponse(TLSResponse):
    def __init__(self, response: Response):
        super(ModifyAlarmResponse, self).__init__(response)


class DescribeAlarmsResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeAlarmsResponse, self).__init__(response)

        self.total = self.response[TOTAL]
        self.alarms = self.response[ALARMS]

        for i in range(len(self.alarms)):
            self.alarms[i] = AlarmInfo.set_attributes(data=self.alarms[i])


class OpenKafkaConsumerResponse(TLSResponse):
    def __init__(self, response: Response):
        super(OpenKafkaConsumerResponse, self).__init__(response)


class CloseKafkaConsumerResponse(TLSResponse):
    def __init__(self, response: Response):
        super(CloseKafkaConsumerResponse, self).__init__(response)


class DescribeKafkaConsumerResponse(TLSResponse):
    def __init__(self, response: Response):
        super(DescribeKafkaConsumerResponse, self).__init__(response)

        self.allow_consume = self.response[ALLOW_CONSUME]
        self.consume_topic = self.response[CONSUME_TOPIC]



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from volcengine.tls.TLSService import TLSService
from volcengine.tls.tls_requests import *


if __name__ == "__main__":
    # 请查询控制台，填写以下参数值
    endpoint = ""
    access_key_id = ""
    access_key_secret = ""
    region = ""

    # 实例化TLS客户端
    tls_service = TLSService(endpoint, access_key_id, access_key_secret, region)

    # 创建日志项目
    create_project_request = CreateProjectRequest(project_name="project-name", region=region,
                                                  description="project-description")
    create_project_response = tls_service.create_project(create_project_request)
    project_id = create_project_response.project_id

    # 创建日志主题
    create_topic_request = CreateTopicRequest(topic_name="topic-name", project_id=project_id,
                                              ttl=3650, description="topic-description", shard_count=2)
    create_topic_response = tls_service.create_topic(create_topic_request)
    topic_id = create_topic_response.topic_id

    # 查询指定日志主题信息
    describe_topic_request = DescribeTopicRequest(topic_id)
    describe_topic_response = tls_service.describe_topic(describe_topic_request)

    # 查询所有日志主题信息
    describe_topics_request = DescribeTopicsRequest(project_id)
    describe_topics_response = tls_service.describe_topics(describe_topics_request)

    # 修改日志主题
    modify_topic_request = ModifyTopicRequest(topic_id, topic_name="change-topic-name",
                                              description="change-topic-description")
    modify_topic_response = tls_service.modify_topic(modify_topic_request)

    # 删除日志主题
    delete_topic_request = DeleteTopicRequest(topic_id)
    delete_topic_response = tls_service.delete_topic(delete_topic_request)



# coding:utf-8
from __future__ import print_function

from volcengine.sts.StsService import StsService
from volcengine.visual.VisualService import VisualService

if __name__ == '__main__':
    # step1 调用AssumeRole接口获取临时ak/sk及token
    # stsService = StsService()
    # stsService.set_ak("your-ak")   # 子账号长期AK
    # stsService.set_sk("your-sk")   # 子账号长期SK
    #
    # params = {
    #     "DurationSeconds": "900",
    #     "RoleSessionName": "just_for_test",
    #     "RoleTrn": "trn:iam::yourAccountID:role/yourRole"
    # }
    #
    # print(stsService.assume_role(params))

    # step2 调用CertToken接口，绑定用户身份
    visual_service = VisualService()

    # call below method if you don't set ak and sk in $HOME/.volc/config
    visual_service.set_ak('your-sts-ak')      # sts返回的临时ak
    visual_service.set_sk('your-sts-sk')      # sts返回的临时sk
    visual_service.set_session_token('your-sts-token')  # sts返回的临时SessionToken
    # visual_service.set_host('host')

    # below shows the sdk usage for all common apis,
    # if you cannot find the needed one, please check other example files in the same dir
    # or contact us for further help

    form = {
        'req_key': 'cert_token',
        'sts_token': 'your-sts-token',
        'tos_info': {},
        'ref_source': '1',
        'liveness_type': 'motion',
        # 'ref_image': '',
        'idcard_name': '',
        'idcard_no': '',
        'liveness_timeout': 10,
        'motion_list': ['0', '1', '2', '3'],
        'fixed_motion_list': ['0'],
        'motion_count': 4,
        'max_liveness_trial': 10,
    }

    # 人脸核身Token接口
    resp = visual_service.cert_token(form)
    print(resp)

    # step3 端上集成-客户端 / h5

    # step4 调用Query接口，查询认证数据
    # visual_service = VisualService()
    #
    # # call below method if you don't set ak and sk in $HOME/.volc/config
    # visual_service.set_ak('sts-ak')      # sts返回的临时ak
    # visual_service.set_sk('sts-sk')      # sts返回的临时sk
    # visual_service.set_session_token('sts-token') # sts返回的临时SessionToken
    # # visual_service.set_host('host')
    #
    # # below shows the sdk usage for all common apis,
    # # if you cannot find the needed one, please check other example files in the same dir
    # # or contact us for further help
    #
    # # x-security-token
    # form = {
    #     'req_key': 'cert_verify_query',
    #     'byted_token': '',
    # }
    #
    # # 人脸核身Query接口
    # resp = visual_service.cert_verify_query(form)
    # print(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/deny_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1flive/business/deny_config.proto\x12\x1fVolcengine.Live.Models.Business\"\xa8\x01\n\x10\x44\x65nyConfigDetail\x12\x0f\n\x07ProType\x18\x01 \x03(\t\x12\x0f\n\x07\x46mtType\x18\x02 \x03(\t\x12\x11\n\tContinent\x18\x03 \x01(\t\x12\x0f\n\x07\x43ountry\x18\x04 \x01(\t\x12\x0e\n\x06Region\x18\x05 \x01(\t\x12\x0c\n\x04\x43ity\x18\x06 \x01(\t\x12\x0b\n\x03ISP\x18\x07 \x01(\t\x12\x10\n\x08\x44\x65nyList\x18\x08 \x03(\t\x12\x11\n\tAllowList\x18\t \x03(\t\"b\n\x18\x44\x65scribeDenyConfigResult\x12\x46\n\x08\x44\x65nyList\x18\x01 \x03(\x0b\x32\x34.Volcengine.Live.Models.Business.VhostWithDenyConfig\"\x88\x01\n\x13VhostWithDenyConfig\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0b\n\x03\x41pp\x18\x03 \x01(\t\x12\x45\n\nDenyConfig\x18\x04 \x03(\x0b\x32\x31.Volcengine.Live.Models.Business.DenyConfigDetailB\xd2\x01\n*com.volcengine.service.live.model.businessB\nDenyConfigP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_DENYCONFIGDETAIL = DESCRIPTOR.message_types_by_name['DenyConfigDetail']
_DESCRIBEDENYCONFIGRESULT = DESCRIPTOR.message_types_by_name['DescribeDenyConfigResult']
_VHOSTWITHDENYCONFIG = DESCRIPTOR.message_types_by_name['VhostWithDenyConfig']
DenyConfigDetail = _reflection.GeneratedProtocolMessageType('DenyConfigDetail', (_message.Message,), {
  'DESCRIPTOR' : _DENYCONFIGDETAIL,
  '__module__' : 'live.business.deny_config_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.DenyConfigDetail)
  })
_sym_db.RegisterMessage(DenyConfigDetail)

DescribeDenyConfigResult = _reflection.GeneratedProtocolMessageType('DescribeDenyConfigResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDENYCONFIGRESULT,
  '__module__' : 'live.business.deny_config_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.DescribeDenyConfigResult)
  })
_sym_db.RegisterMessage(DescribeDenyConfigResult)

VhostWithDenyConfig = _reflection.GeneratedProtocolMessageType('VhostWithDenyConfig', (_message.Message,), {
  'DESCRIPTOR' : _VHOSTWITHDENYCONFIG,
  '__module__' : 'live.business.deny_config_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.VhostWithDenyConfig)
  })
_sym_db.RegisterMessage(VhostWithDenyConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\nDenyConfigP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _DENYCONFIGDETAIL._serialized_start=69
  _DENYCONFIGDETAIL._serialized_end=237
  _DESCRIBEDENYCONFIGRESULT._serialized_start=239
  _DESCRIBEDENYCONFIGRESULT._serialized_end=337
  _VHOSTWITHDENYCONFIG._serialized_start=340
  _VHOSTWITHDENYCONFIG._serialized_end=476
# @@protoc_insertion_point(module_scope)



# coding:utf-8

from volcengine.sts.StsService import StsService

if __name__ == '__main__':
    stsService = StsService()
    stsService.set_ak("your ak")
    stsService.set_sk("your sk")

    params = {
        "DurationSeconds": "900",
        "RoleSessionName": "just_for_test",
        "RoleTrn": "trn:iam::yourAccountID:role/yourRole"
    }

    print(stsService.assume_role(params))



# coding:utf-8
from __future__ import print_function

from volcengine.bioos.BioOsService import BioOsService

import json


if __name__ == '__main__':
    # set endpoint/region here if the default value is unsatisfied
    bioos_service = BioOsService(endpoint='endpoint', region='region')

    # call below method if you don't set ak and sk in $HOME/.volc/config
    bioos_service.set_ak('ak')
    bioos_service.set_sk('sk')

    params = {
        'ClusterID': 'cluster_id',
        'WorkspaceID': 'workspace_id',
        'WorkflowID': 'workflow_id',
        'Name': 'submission_name',
        'Description': 'submission_description',
        'DataModelID': 'data_model_id',
        'DataModelRowIDs': ['your-sample-3-id'],
        'Inputs': json.dumps({
            'testname.hello.name': 'this.name1'
        }),
        'ExposedOptions': {'ReadFromCache': True},
        'Outputs': json.dumps({
            'testname.hello.response': 'this.response1'
        }),
    }

    resp = bioos_service.create_submission(params)
    print(resp)



#  -*- coding: utf-8 -*-
import os
import sys

sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../../")

from volcengine.example.dcdn import ak, sk
from volcengine.dcdn.DCDNService import DCDNService

if __name__ == '__main__':
    svc = DCDNService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = {
        "Domains": ["www.test.com"]
    }

    resp = svc.delete_domain(body)
    print(resp)



# coding:utf-8
from __future__ import print_function

import json

from volcengine.const.Const import REGION_AP_SINGAPORE1, AREA_OVERSEAS
from volcengine.sms.SmsService import SmsService

if __name__ == '__main__':
    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)
    # cn
    sms_service = SmsService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_scheme("http")
    # sms_service.set_scheme("https")
    # sms_service.set_host('host')¬

    param = {
        "subAccount": "subAccount",
        "signature": "sign",
        "pageIndex": 1,
        "pageSize": 10
    }

    resp = sms_service.get_signature_and_order_list(param)
    print(resp)



# coding:utf-8
import json
import threading

from retry import retry

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service


class NumberPoolService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(NumberPoolService, "_instance"):
            with NumberPoolService._instance_lock:
                if not hasattr(NumberPoolService, "_instance"):
                    NumberPoolService._instance = object.__new__(cls)
        return NumberPoolService._instance

    def __init__(self, region='cn-north-1'):
        self.service_info = NumberPoolService.get_service_info(region)
        self.api_info = NumberPoolService.get_api_info()
        self.domain_cache = {}
        self.fallback_domain_weights = {}
        self.update_interval = 10
        self.lock = threading.Lock()
        super(NumberPoolService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info_map = {
            'cn-north-1': ServiceInfo("cloud-vms.volcengineapi.com", {'Accept': 'application/json'},
                                      Credentials('', '', 'comm_number_pool', 'cn-north-1'), 10, 10),
        }
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('Cant find the region, please check it carefully')

        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "NumberPoolList": ApiInfo("POST", "/", {"Action": "NumberPoolList", "Version": "2020-09-01"}, {}, {}),
            "NumberList": ApiInfo("GET", "/", {"Action": "NumberList", "Version": "2020-09-01"}, {}, {}),
            "CreateNumberPool": ApiInfo("POST", "/", {"Action": "CreateNumberPool", "Version": "2020-09-01"}, {}, {}),
            "UpdateNumberPool": ApiInfo("POST", "/", {"Action": "UpdateNumberPool", "Version": "2020-09-01"}, {}, {}),
            "EnableOrDisableNumber": ApiInfo("POST", "/", {"Action": "EnableOrDisableNumber", "Version": "2021-01-01"}, {}, {}),
            "SelectNumber": ApiInfo("GET", "/", {"Action": "SelectNumber", "Version": "2021-01-01"}, {}, {}),

        }
        return api_info

    def common_handler(self, api, form):
        params = dict()
        try:
            res = self.post(api, params, form)
            res_json = json.loads(res)
            return res_json
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    def do_query_handler(self, api, params):
        try:
            res = self.get(api, params)
            return json.loads(res)
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    @retry(tries=2, delay=0)
    def number_pool_list(self, form):
        try:
            return self.common_handler("NumberPoolList", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def number_list(self, params):
        try:
            return self.do_query_handler("NumberList", params)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def create_number_pool(self, form):
        try:
            return self.common_handler("CreateNumberPool", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def update_number_pool(self, form):
        try:
            return self.common_handler("UpdateNumberPool", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def enable_or_disable_number(self, form):
        try:
            return self.common_handler("EnableOrDisableNumber", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def select_number(self, params):
        try:
            return self.do_query_handler("SelectNumber", params)
        except Exception as e:
            raise Exception(str(e))






from tokenize import String


class CreateVQScoreTaskRequest:
    MainAddr = ""
    ContrastAddr = ""
    FrameInterval = 0
    Duration = 0
    Algorithm = ""
    def __init__(self):
        self = self

class GeneratePushURLRequest:
    Vhost = ""
    Domain = ""
    App = ""
    Stream = ""
    ValidDuration = 0
    ExpiredTime = ""
    def __init__(self):
        self = self

class GeneratePlayURLRequest:
    Vhost = ""
    Domain = ""
    App = ""
    Stream = ""
    Suffix = ""
    Type = ""
    ValidDuration = 0
    ExpiredTime = ""
    def __init__(self):
        self = self

class CreatePullToPushTaskRequest:
    Title = ""
    StartTime = 0
    EndTime = 0
    CallbackURL = ""
    Type = 0
    CycleMode = 0
    DstAddr = ""
    SrcAddr = ""
    SrcAddrS = []
    def __init__(self):
        self = self

class UpdatePullToPushTaskRequest:
    Title = ""
    StartTime = 0
    EndTime = 0
    CallbackURL = ""
    Type = 0
    CycleMode = 0
    DstAddr = ""
    SrcAddr = ""
    SrcAddrS = []
    TaskId = ""
    def __init__(self):
        self = self

class ListVQScoreTaskRequest:
    StartTime = ""
    EndTime = ""
    PageNum = 0
    PageSize = 0
    Status = 0
    def __init__(self):
        self = self


# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.request_live_pb2 import UpdateRelaySourceRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('==')
    req = UpdateRelaySourceRequest()
    req.Vhost = 'Vhost'
    req.App = 'App'
    req.RelaySourceProtocol = 'RelaySourceProtocol'
    req.RelaySourceDomainList.extend(['RelaySourceDomainList'])
    print(req)
    resp = live_service.update_relay_source_v2(req)
    print(resp)




# coding:utf-8
from __future__ import print_function

import json

from volcengine.const.Const import *
from volcengine.sms.SmsService import SmsService

if __name__ == '__main__':
    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)
    # cn
    sms_service = SmsService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_scheme("http")
    # sms_service.set_scheme("https")
    # sms_service.set_host('host')

    body = {
        "SubAccount": "subAccount",
        "Area": AREA_CN,
        "ChannelType": SMS_CHANNEL_TYPE_CN_MKT,
        "Content": "We're offering our xxxx community 20% off with code THANKYOU. It's our way of showing our "
                   "appreciation to you for standing by us in this time. Shop Now: "
                   "https://webhook.site/edd2b39a-6c8d-4161-a310-36a470c840d4 T退订",
        "Desc": "description",
        "Name": "template_name",
        "ShortUrlConfig": {
            "IsEnabled": ENABLE_STATUS_ENABLE,
            "IsNeedClickDetails": ENABLE_STATUS_NOT_ENABLE
        }
    }

    resp = sms_service.apply_sms_template(body)
    print(resp)



#  -*- coding: utf-8 -*-
import os
import sys

sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../../")

from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = {
        'Domain': 'example.com',
        'Origin': [
            {
                'OriginAction': {
                    'OriginLines': [{
                        'OriginType': 'primary',
                        'InstanceType': 'domain',
                        'Address': 'new-origin.com',
                        'HttpPort': '80',
                        'HttpsPort': '443',
                        'Weight': '100'
                    }]
                }
            }
        ],
    }

    resp = svc.update_cdn_config(body)
    print(resp)



# coding:utf-8
from volcengine.vms.NumberPoolService import NumberPoolService

if __name__ == '__main__':
    numberPoolService = NumberPoolService()

    numberPoolService.set_ak("your ak")
    numberPoolService.set_sk("your sk")

form = {
    "NumberPoolNo": "xxx"

}
print(numberPoolService.select_number(form))



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')
    body = {
        "Domain": "your domain",
        "App": "your app",
        "Stream": "your stream",
        "StartTime": "2022-12-22T19:35:00Z",
        "EndTime": "2022-12-22T19:40:05Z",
        "OutputBucket": "your bucket"
    }
    resp = live_service.create_live_stream_record_index_files(body)
    print(resp)



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    params = {
       "ResourceKey": "1ca08a45a937411ebd78e572cef87086",
       "Name": "123.mp3"
    }

    print(notify_service.open_update_resource(params))



# coding:utf-8
import json
import os
from six.moves import queue
import threading
from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service
from volcengine.const.Const import *
from volcengine.util.Util import *
from volcengine.Policy import *
from volcengine.imagex.ImageXConfig import *
from retry import retry


class Uploader:
    def __init__(self, imagex_service, host, store_infos=None, file_paths_or_bytes=None):
        if store_infos is None:
            store_infos = []
        if file_paths_or_bytes is None:
            file_paths_or_bytes = []

        self.imagex_service = imagex_service
        self.host = host
        self.store_infos = store_infos
        self.file_paths_or_bytes = file_paths_or_bytes

        self.queue = queue.Queue()
        self.queue_lock = threading.Lock()

        for i in range(len(store_infos)):
            self.queue.put(i)

    def async_upload(self):
        while not self.queue.empty():
            self.queue_lock.acquire()
            if self.queue.empty():
                self.queue_lock.release()
                break
            idx = self.queue.get()
            self.queue_lock.release()

            store_info = self.store_infos[idx]
            file_paths_or_bytes = self.file_paths_or_bytes[idx]

            if isinstance(file_paths_or_bytes, bytes):
                self.upload_by_host(store_info, file_paths_or_bytes)
            elif isinstance(file_paths_or_bytes, str):
                file_path = file_paths_or_bytes
                file_size = os.path.getsize(file_path)
                data = open(file_path, "rb")
                if file_size < MinChunkSize:
                    self.upload_by_host(store_info, data.read())
                elif file_size > LargeFileSize:
                    self.chunk_upload(store_info, data, file_size, True)
                else:
                    self.chunk_upload(store_info, data, file_size, False)
                data.close()
            else:
                raise Exception("Uploader only accept bytes or path data")

    @retry(tries=3, delay=1, backoff=2)
    def upload_by_host(self, store_info, img_data):
        url = 'https://{}/{}'.format(self.host, store_info['StoreUri'])
        check_sum = crc32(img_data) & 0xFFFFFFFF
        check_sum = "%08x" % check_sum
        headers = {'Content-CRC32': check_sum, 'Authorization': store_info['Auth']}
        upload_status, resp = self.imagex_service.put_data(url, img_data, headers)
        if not upload_status:
            raise Exception('upload by host: upload url %s status false, resp: %s' % (url, resp))

    def chunk_upload(self, store_info, f, size, is_large_file):
        upload_id = self.init_upload_part(store_info, is_large_file)
        n = size // MinChunkSize
        last_num = n - 1
        parts = []
        for i in range(0, last_num):
            data = f.read(MinChunkSize)
            part_number = i
            if is_large_file:
                part_number = i + 1
            part = self.upload_part(store_info, upload_id, part_number, data, is_large_file)
            parts.append(part)
        data = f.read()
        if is_large_file:
            last_num = last_num + 1
        part = self.upload_part(store_info, upload_id, last_num, data, is_large_file)
        parts.append(part)
        return self.upload_merge_part(store_info, upload_id, parts, is_large_file)

    @retry(tries=3, delay=1, backoff=2)
    def init_upload_part(self, store_info, is_large_file):
        url = 'https://{}/{}?uploads'.format(self.host, store_info['StoreUri'])
        headers = {'Authorization': store_info['Auth']}
        if is_large_file:
            headers['X-Storage-Mode'] = 'gateway'
        upload_status, resp = self.imagex_service.put_data(url, None, headers)
        resp = json.loads(resp)
        if not upload_status:
            raise Exception("init upload error")
        if resp.get('success') is None or resp['success'] != 0:
            raise Exception("init upload error")
        return resp['payload']['uploadID']

    @retry(tries=3, delay=1, backoff=2)
    def upload_part(self, store_info, upload_id, part_number, data, is_large_file):
        url = 'https://{}/{}?partNumber={}&uploadID={}'.format(self.host, store_info['StoreUri'], part_number, upload_id)
        check_sum = crc32(data) & 0xFFFFFFFF
        check_sum = "%08x" % check_sum
        headers = {'Content-CRC32': check_sum, 'Authorization': store_info['Auth']}
        if is_large_file:
            headers['X-Storage-Mode'] = 'gateway'
        upload_status, resp = self.imagex_service.put_data(url, data, headers)
        if not upload_status:
            raise Exception(url + json.dumps(resp))
        resp = json.loads(resp)
        if resp.get('success') is None or resp['success'] != 0:
            raise Exception("upload part error")
        return check_sum

    # noinspection DuplicatedCode
    @staticmethod
    def generate_merge_body(check_sum_list):
        if len(check_sum_list) == 0:
            raise Exception('crc32 list empty')
        s = []
        for i in range(len(check_sum_list)):
            s.append('{}:{}'.format(i, check_sum_list[i]))
        comma = ','
        return comma.join(s)

    @retry(tries=3, delay=1, backoff=2)
    def upload_merge_part(self, store_info, upload_id, check_sum_list, is_large_file):
        url = 'https://{}/{}?uploadID={}'.format(self.host, store_info['StoreUri'], upload_id)
        data = self.generate_merge_body(check_sum_list)
        headers = {'Authorization': store_info['Auth']}
        if is_large_file:
            headers['X-Storage-Mode'] = 'gateway'
        upload_status, resp = self.imagex_service.put_data(url, data, headers)
        resp = json.loads(resp)
        if not upload_status:
            raise Exception("init upload error")
        if resp.get('success') is None or resp['success'] != 0:
            raise Exception("init upload error")

class ImageXService(Service):
    def __init__(self, region=REGION_CN_NORTH1):
        self.service_info = ImageXService.get_service_info(region)
        self.api_info = ImageXService.get_api_info()
        super(ImageXService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('ImageX not support region %s' % region)
        return service_info

    @staticmethod
    def get_api_info():
        return api_info

    # upload
    def apply_upload(self, params):
        res = self.get('ApplyImageUpload', params, doseq=1)
        if res == '':
            raise Exception("ApplyImageUpload: empty response")
        res_json = json.loads(res)
        return res_json

    def commit_upload(self, params, body):
        res = self.json('CommitImageUpload', params, body)
        if res == '':
            raise Exception("CommitImageUpload: empty response")
        res_json = json.loads(res)
        return res_json

    # upload local image file
    # noinspection DuplicatedCode
    def upload_image(self, params, file_paths):
        for p in file_paths:
            if not os.path.isfile(p):
                raise Exception("no such file on file path %s" % p)

        apply_upload_request = {
            'ServiceId': params['ServiceId'],
            'SessionKey': params.get('SessionKey', ''),
            'UploadNum': len(file_paths),
            'StoreKeys': params.get('StoreKeys', []),
        }
        resp = self.apply_upload(apply_upload_request)
        if 'Error' in resp['ResponseMetadata']:
            raise Exception(resp['ResponseMetadata'])

        result = resp['Result']
        reqid = result['RequestId']
        addr = result['UploadAddress']
        if len(addr['UploadHosts']) == 0:
            raise Exception("no upload host found, reqid %s" % reqid)
        elif len(addr['StoreInfos']) != len(file_paths):
            raise Exception("store info len %d != upload num %d, reqid %s" % (
                len(result['StoreInfos']), len(file_paths), reqid))

        session_key = addr['SessionKey']
        host = addr['UploadHosts'][0]
        self.do_upload(file_paths, host, addr['StoreInfos'])

        commit_upload_request = {
            'ServiceId': params['ServiceId'],
        }
        commit_upload_body = {
            'SessionKey': session_key,
            'Functions': params.get('Functions', []),
            'OptionInfos': params.get('OptionInfos', [])
        }
        resp = self.commit_upload(
            commit_upload_request, json.dumps(commit_upload_body))
        if 'Error' in resp['ResponseMetadata']:
            raise Exception(resp['ResponseMetadata'])
        return resp['Result']

    # upload image data
    # noinspection DuplicatedCode
    def upload_image_data(self, params, img_datas):
        for data in img_datas:
            if not isinstance(data, bytes):
                raise Exception("upload of non-bytes not supported")

        apply_upload_request = {
            'ServiceId': params['ServiceId'],
            'SessionKey': params.get('SessionKey', ''),
            'UploadNum': len(img_datas),
            'StoreKeys': params.get('StoreKeys', []),
        }
        resp = self.apply_upload(apply_upload_request)
        if 'Error' in resp['ResponseMetadata']:
            raise Exception(resp['ResponseMetadata'])

        result = resp['Result']
        reqid = result['RequestId']
        addr = result['UploadAddress']
        if len(addr['UploadHosts']) == 0:
            raise Exception("no upload host found, reqid %s" % reqid)
        elif len(addr['StoreInfos']) != len(img_datas):
            raise Exception("store info len %d != upload num %d, reqid %s" % (
                len(result['StoreInfos']), len(img_datas), reqid))

        session_key = addr['SessionKey']
        host = addr['UploadHosts'][0]
        self.do_upload(img_datas, host, addr['StoreInfos'])

        commit_upload_request = {
            'ServiceId': params['ServiceId'],
        }
        commit_upload_body = {
            'SessionKey': session_key,
            'Functions': params.get('Functions', []),
            'OptionInfos': params.get('OptionInfos', [])
        }
        resp = self.commit_upload(
            commit_upload_request, json.dumps(commit_upload_body))
        if 'Error' in resp['ResponseMetadata']:
            raise Exception(resp['ResponseMetadata'])
        return resp['Result']

    def do_upload(self, file_paths_or_bytes, host, store_infos):
        threads = []
        uploader = Uploader(self, host, store_infos, file_paths_or_bytes)
        for i in range(UPLOAD_THREADS):
            thread = threading.Thread(target=uploader.async_upload)
            thread.start()
            threads.append(thread)

        for i in range(UPLOAD_THREADS):
            threads[i].join()

    def get_upload_auth_token(self, params):
        apply_token = self.get_sign_url('ApplyImageUpload', params)
        commit_token = self.get_sign_url('CommitImageUpload', params)

        ret = {'Version': 'v1', 'ApplyUploadToken': apply_token,
               'CommitUploadToken': commit_token}
        data = json.dumps(ret)
        if sys.version_info[0] == 3:
            return base64.b64encode(data.encode('utf-8')).decode('utf-8')
        else:
            return base64.b64encode(data.decode('utf-8'))

    def get_upload_auth(self, service_ids, expire=60 * 60, key_ptn=''):
        apply_res = []
        commit_res = []
        if len(service_ids) == 0:
            apply_res.append(ResourceServiceIdTRN % '*')
            commit_res.append(ResourceServiceIdTRN % '*')
        else:
            for sid in service_ids:
                apply_res.append(ResourceServiceIdTRN % sid)
                commit_res.append(ResourceServiceIdTRN % sid)
        apply_res.append(ResourceStoreKeyTRN % key_ptn)

        inline_policy = Policy([
            Statement.new_allow_statement(
                ['ImageX:ApplyImageUpload'], apply_res),
            Statement.new_allow_statement(
                ['ImageX:CommitImageUpload'], commit_res)
        ])
        return self.sign_sts2(inline_policy, expire)

    def delete_images(self, service_id, uris):
        query = {
            'ServiceId': service_id
        }
        body = {
            'StoreUris': uris
        }
        res = self.json('DeleteImageUploadFiles', query, json.dumps(body))
        if res == '':
            raise Exception("DeleteImageUploadFiles: empty response")
        res_json = json.loads(res)
        if 'Error' in res_json['ResponseMetadata']:
            raise Exception(res_json['ResponseMetadata'])
        return res_json['Result']

    def update_image_urls(self, service_id, urls, action=0):
        query = {
            'ServiceId': service_id
        }
        body = {
            'Action': action,
            'ImageUrls': urls
        }
        res = self.json("UpdateImageUploadFiles", query, json.dumps(body))
        if res == '':
            raise Exception("UpdateImageUploadFiles: empty response")
        res_json = json.loads(res)
        if 'Error' in res_json['ResponseMetadata']:
            raise Exception(res_json['ResponseMetadata'])
        return res_json['Result']

    def get_image_info(self, service_id, store_uri):
        query = {
            'ServiceId': service_id,
            'StoreUri': store_uri,
        }
        res = self.get('PreviewImageUploadFile', query)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        if 'Error' in res_json['ResponseMetadata']:
            raise Exception(res_json['ResponseMetadata'])
        return res_json['Result']

    def imagex_get(self, action, params, doseq=0):
        res = self.get(action, params, doseq)
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(json.dumps(res))
        return res_json

    def imagex_post(self, action, params, body):
        res = self.json(action, params, body)
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(json.dumps(res))
        return res_json

    def fetch_image_url(self, request):
        res = self.imagex_post('FetchImageUrl', request, json.dumps(request))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        if 'Error' in res_json['ResponseMetadata']:
            raise Exception(res_json['ResponseMetadata'])
        return res_json['Result']

    def get_image_ocr(self, params):
        res = self.post('GetImageOCR', params, {})
        if res == '':
            raise Exception("%s: empty response" % 'GetImageOCR')
        res_json = json.loads(res)
        return res_json

    def get_image_segment(self, params):
        res = self.post('GetSegmentImage', params, {})
        if res == '':
            raise Exception("%s: empty response" % 'GetSegmentImage')
        res_json = json.loads(res)
        return res_json

    def get_image_quality(self, params):
        body = {
            'ImageUrl': params['ImageUrl'],
            'VqType': params.get('VqType', None)
        }
        res = self.imagex_post('GetImageQuality', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageQuality')
        res_json = json.loads(res)
        return res_json

    def get_image_erase_models(self, params):
        res = self.imagex_get('GetImageEraseModels', params)
        if res == '':
            raise Exception("%s: empty response" % 'GetImageEraseModels')
        res_json = json.loads(res)
        return res_json

    def get_image_erase_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri'],
            'Model': params['Model'],
            'BBox': params.get('BBox', None)
        }
        res = self.imagex_post('GetImageEraseResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageEraseResult')
        res_json = json.loads(res)
        return res_json

    def get_image_enhance_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri'],
            'Model': params['Model'],
            'DisableAr': params.get('DisableAr', None),
            'DisableSharp': params.get('DisableSharp', None),
            'Resolution': params.get('Resolution', None)
        }
        res = self.imagex_post('GetImageEnhanceResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageEnhanceResult')
        res_json = json.loads(res)
        return res_json

    def get_image_bg_fill_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri'],
            'Model': params['Model'],
            'Top': params.get('Top', None),
            'Bottom': params.get('Bottom', None),
            'Left': params.get('Left', None),
            'Right': params.get('Right', None)
        }
        res = self.imagex_post('GetImageBgFillResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageBgFillResult')
        res_json = json.loads(res)
        return res_json

    def get_image_comic_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri']
        }
        res = self.imagex_post('GetImageComicResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageComicResult')
        res_json = json.loads(res)
        return res_json

    def get_image_super_resolution_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri'],
            'Multiple': params.get('Multiple', None)
        }
        res = self.imagex_post('GetImageSuperResolutionResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageSuperResolutionResult')
        res_json = json.loads(res)
        return res_json

    def get_license_plate_detection(self, params):
        body = {
            'ImageUri': params['ImageUri']
        }
        res = self.imagex_post('GetLicensePlateDetection', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetLicensePlateDetection')
        res_json = json.loads(res)
        return res_json



# coding:utf-8
from __future__ import print_function

import json

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodSubmitDirectEditTaskAsyncRequest

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('ak')
    vod_service.set_sk('sk')
    req = VodSubmitDirectEditTaskAsyncRequest()
    req.Uploader = 'your uploader'
    req.Application = 'VideoTrackToB'
    req.Priority = 0
    req.CallbackUri = 'your callback uri'
    req.CallbackArgs = 'your callback args'
    editParam = {
        "Canvas": {
            "Height": 2160,
            "Width": 3840
        },
        "Output": {
            "Alpha": False,
            "Codec": {
                "AudioBitrate": 128,
                "AudioCodec": "aac",
                "Crf": 23,
                "Preset": "slow",
                "VideoCodec": "h264"
            },
            "DisableAudio": False,
            "DisableVideo": False,
            "Fps": 30
        },
        "Track": [
            [
                {
                    "ID": "video1",
                    "Source": "your source",
                    "TargetTime": [
                        0,
                        10000
                    ],
                    "Type": "video"
                }
            ]
        ],
        "Upload": {
            "SpaceName": "your uploader",
            "VideoName": "your video name"
        },
        "Uploader": "your uploader"
    }
    req.EditParam = json.dumps(editParam)
    resp = vod_service.submit_direct_edit_task_async(req)
    l = json.loads(resp)
    print(json.dumps(l, ensure_ascii=False, indent=4))
    print("****")



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.request_live_pb2 import DescribeForbiddenStreamInfoByPageRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')
    req = DescribeForbiddenStreamInfoByPageRequest()
    req.PageNum = 0
    req.PageSize = 0
    req.App = 'App'
    req.Stream = 'Stream'
    print(req)
    resp = live_service.describe_forbidden_stream_info_by_page(req)
    print(resp)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/relay_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n live/business/relay_source.proto\x12\x1fVolcengine.Live.Models.Business\"\xf9\x01\n\x16RelaySourceGroupItemV2\x12\x1d\n\x15RelaySourceDomainList\x18\x01 \x03(\t\x12i\n\x11RelaySourceParams\x18\x02 \x03(\x0b\x32N.Volcengine.Live.Models.Business.RelaySourceGroupItemV2.RelaySourceParamsEntry\x12\x1b\n\x13RelaySourceProtocol\x18\x03 \x01(\t\x1a\x38\n\x16RelaySourceParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x11RelaySourceConfig\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0b\n\x03\x41pp\x18\x02 \x01(\t\x12J\n\tGroupList\x18\x03 \x03(\x0b\x32\x37.Volcengine.Live.Models.Business.RelaySourceGroupItemV2\"f\n\x15RelaySourceConfigList\x12M\n\x11RelaySourceConfig\x18\x01 \x03(\x0b\x32\x32.Volcengine.Live.Models.Business.RelaySourceConfigB\xd3\x01\n*com.volcengine.service.live.model.businessB\x0bRelaySourceP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_RELAYSOURCEGROUPITEMV2 = DESCRIPTOR.message_types_by_name['RelaySourceGroupItemV2']
_RELAYSOURCEGROUPITEMV2_RELAYSOURCEPARAMSENTRY = _RELAYSOURCEGROUPITEMV2.nested_types_by_name['RelaySourceParamsEntry']
_RELAYSOURCECONFIG = DESCRIPTOR.message_types_by_name['RelaySourceConfig']
_RELAYSOURCECONFIGLIST = DESCRIPTOR.message_types_by_name['RelaySourceConfigList']
RelaySourceGroupItemV2 = _reflection.GeneratedProtocolMessageType('RelaySourceGroupItemV2', (_message.Message,), {

  'RelaySourceParamsEntry' : _reflection.GeneratedProtocolMessageType('RelaySourceParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RELAYSOURCEGROUPITEMV2_RELAYSOURCEPARAMSENTRY,
    '__module__' : 'live.business.relay_source_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.RelaySourceGroupItemV2.RelaySourceParamsEntry)
    })
  ,
  'DESCRIPTOR' : _RELAYSOURCEGROUPITEMV2,
  '__module__' : 'live.business.relay_source_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.RelaySourceGroupItemV2)
  })
_sym_db.RegisterMessage(RelaySourceGroupItemV2)
_sym_db.RegisterMessage(RelaySourceGroupItemV2.RelaySourceParamsEntry)

RelaySourceConfig = _reflection.GeneratedProtocolMessageType('RelaySourceConfig', (_message.Message,), {
  'DESCRIPTOR' : _RELAYSOURCECONFIG,
  '__module__' : 'live.business.relay_source_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.RelaySourceConfig)
  })
_sym_db.RegisterMessage(RelaySourceConfig)

RelaySourceConfigList = _reflection.GeneratedProtocolMessageType('RelaySourceConfigList', (_message.Message,), {
  'DESCRIPTOR' : _RELAYSOURCECONFIGLIST,
  '__module__' : 'live.business.relay_source_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.RelaySourceConfigList)
  })
_sym_db.RegisterMessage(RelaySourceConfigList)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\013RelaySourceP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _RELAYSOURCEGROUPITEMV2_RELAYSOURCEPARAMSENTRY._options = None
  _RELAYSOURCEGROUPITEMV2_RELAYSOURCEPARAMSENTRY._serialized_options = b'8\001'
  _RELAYSOURCEGROUPITEMV2._serialized_start=70
  _RELAYSOURCEGROUPITEMV2._serialized_end=319
  _RELAYSOURCEGROUPITEMV2_RELAYSOURCEPARAMSENTRY._serialized_start=263
  _RELAYSOURCEGROUPITEMV2_RELAYSOURCEPARAMSENTRY._serialized_end=319
  _RELAYSOURCECONFIG._serialized_start=321
  _RELAYSOURCECONFIG._serialized_end=444
  _RELAYSOURCECONFIGLIST._serialized_start=446
  _RELAYSOURCECONFIGLIST._serialized_end=548
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.const.Const import *

IMAGEX_SERVICE_NAME = "ImageX"
IMAGEX_API_VERSION = "2018-08-01"

ResourceServiceIdTRN = "trn:ImageX:*:*:ServiceId/%s"
ResourceStoreKeyTRN = "trn:ImageX:*:*:StoreKeys/%s"

UPLOAD_THREADS = 3

MinChunkSize = 1024 * 1024 * 20
LargeFileSize = 1024 * 1024 * 1024

service_info_map = {
    REGION_CN_NORTH1: ServiceInfo(
        "imagex.volcengineapi.com",
        {'Accept': 'application/json'},
        Credentials('', '', IMAGEX_SERVICE_NAME, REGION_CN_NORTH1),
        10, 10, "https"),
    REGION_AP_SINGAPORE1: ServiceInfo(
        "imagex-ap-singapore-1.volcengineapi.com",
        {'Accept': 'application/json'},
        Credentials('', '', IMAGEX_SERVICE_NAME, REGION_AP_SINGAPORE1),
        10, 10, "https"),
    REGION_US_EAST1: ServiceInfo(
        "imagex-us-east-1.volcengineapi.com",
        {'Accept': 'application/json'},
        Credentials('', '', IMAGEX_SERVICE_NAME, REGION_US_EAST1),
        10, 10, "https"),
}

api_info = {
    "GetImageServiceSubscription":
        ApiInfo("GET", "/", {"Action": "GetImageServiceSubscription", "Version": IMAGEX_API_VERSION}, {}, {}),
    "CreateImageService":
        ApiInfo("POST", "/", {"Action": "CreateImageService", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageService":
        ApiInfo("GET", "/", {"Action": "GetImageService", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetAllImageServices":
        ApiInfo("GET", "/", {"Action": "GetAllImageServices", "Version": IMAGEX_API_VERSION}, {}, {}),
    "DeleteImageService":
        ApiInfo("POST", "/", {"Action": "DeleteImageService", "Version": IMAGEX_API_VERSION}, {}, {}),
    "UpdateImageAuthKey":
        ApiInfo("POST", "/", {"Action": "UpdateImageAuthKey", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageAuthKey":
        ApiInfo("GET", "/", {"Action": "GetImageAuthKey", "Version": IMAGEX_API_VERSION}, {}, {}),
    "UpdateImageObjectAccess":
        ApiInfo("POST", "/", {"Action": "UpdateImageObjectAccess", "Version": IMAGEX_API_VERSION}, {}, {}),
    "UpdateImageMirrorConf":
        ApiInfo("POST", "/", {"Action": "UpdateImageMirrorConf", "Version": IMAGEX_API_VERSION}, {}, {}),
    "DelDomain":
        ApiInfo("POST", "/", {"Action": "DelDomain", "Version": IMAGEX_API_VERSION}, {}, {}),

    # 域名管理
    "GetServiceDomains":
        ApiInfo("GET", "/", {"Action": "GetServiceDomains", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetDomainConfig":
        ApiInfo("GET", "/", {"Action": "GetDomainConfig", "Version": IMAGEX_API_VERSION}, {}, {}),
    "SetDefaultDomain":
        ApiInfo("POST", "/", {"Action": "SetDefaultDomain", "Version": IMAGEX_API_VERSION}, {}, {}),
    "UpdateResponseHeader":
        ApiInfo("POST", "/", {"Action": "UpdateResponseHeader", "Version": IMAGEX_API_VERSION}, {}, {}),
    "UpdateRefer":
        ApiInfo("POST", "/", {"Action": "UpdateRefer", "Version": IMAGEX_API_VERSION}, {}, {}),
    "UpdateHttps":
        ApiInfo("POST", "/", {"Action": "UpdateHttps", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetResponseHeaderValidateKeys":
        ApiInfo("GET", "/", {"Action": "GetResponseHeaderValidateKeys", "Version": IMAGEX_API_VERSION}, {}, {}),

    # 模板管理
    "CreateImageTemplate":
        ApiInfo("POST", "/", {"Action": "CreateImageTemplate", "Version": IMAGEX_API_VERSION}, {}, {}),
    "DeleteImageTemplate":
        ApiInfo("POST", "/", {"Action": "DeleteImageTemplate", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageTemplate":
        ApiInfo("GET", "/", {"Action": "GetImageTemplate", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetAllImageTemplates":
        ApiInfo("GET", "/", {"Action": "GetAllImageTemplates", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetTemplatesFromBin":
        ApiInfo("GET", "/", {"Action": "GetTemplatesFromBin", "Version": IMAGEX_API_VERSION}, {}, {}),
    "CreateTemplatesFromBin":
        ApiInfo("POST", "/", {"Action": "CreateTemplatesFromBin", "Version": IMAGEX_API_VERSION}, {}, {}),
    "DeleteTemplatesFromBin":
        ApiInfo("POST", "/", {"Action": "DeleteTemplatesFromBin", "Version": IMAGEX_API_VERSION}, {}, {}),

    # 资源管理相关
    "ApplyImageUpload":
        ApiInfo("GET", "/", {"Action": "ApplyImageUpload", "Version": IMAGEX_API_VERSION}, {}, {}),
    "CommitImageUpload":
        ApiInfo("POST", "/", {"Action": "CommitImageUpload", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageUploadFile":
        ApiInfo("GET", "/", {"Action": "GetImageUploadFile", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageUploadFiles":
        ApiInfo("GET", "/", {"Action": "GetImageUploadFiles", "Version": IMAGEX_API_VERSION}, {}, {}),
    "DeleteImageUploadFiles":
        ApiInfo("POST", "/", {"Action": "DeleteImageUploadFiles", "Version": IMAGEX_API_VERSION}, {}, {}),
    "PreviewImageUploadFile":
        ApiInfo("GET", "/", {"Action": "PreviewImageUploadFile", "Version": IMAGEX_API_VERSION}, {}, {}),
    "UpdateImageUploadFiles":
        ApiInfo("POST", "/", {"Action": "UpdateImageUploadFiles", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageUpdateFiles":
        ApiInfo("GET", "/", {"Action": "GetImageUpdateFiles", "Version": IMAGEX_API_VERSION}, {}, {}),
    "FetchImageUrl":
        ApiInfo("POST", "/", {"Action": "FetchImageUrl", "Version": IMAGEX_API_VERSION}, {}, {}),

    "UpdateServiceName":
        ApiInfo("POST", "/", {"Action": "UpdateServiceName", "Version": IMAGEX_API_VERSION}, {}, {}),

    # 其他 API
    "GetImageOCR":
        ApiInfo("POST", "/", {"Action": "GetImageOCR", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageQuality":
        ApiInfo("POST", "/", {"Action": "GetImageQuality", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageEraseModels":
        ApiInfo("GET", "/", {"Action": "GetImageEraseModels", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageEnhanceResult":
        ApiInfo("POST", "/", {"Action": "GetImageEnhanceResult", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageBgFillResult":
        ApiInfo("POST", "/", {"Action": "GetImageBgFillResult", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageDuplicateDetection":
        ApiInfo("POST", "/", {"Action": "GetImageDuplicateDetection", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetDenoisingImage":
        ApiInfo("POST", "/", {"Action": "GetDenoisingImage", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetSegmentImage":
        ApiInfo("POST", "/", {"Action": "GetSegmentImage", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageComicResult":
        ApiInfo("POST", "/", {"Action": "GetImageComicResult", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageSuperResolutionResult":
        ApiInfo("POST", "/", {"Action": "GetImageSuperResolutionResult", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageSmartCropResult":
        ApiInfo("POST", "/", {"Action": "GetImageSmartCropResult", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetLicensePlateDetection":
        ApiInfo("POST", "/", {"Action": "GetLicensePlateDetection", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImagePSDetection":
        ApiInfo("POST", "/", {"Action": "GetImagePSDetection", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetPrivateImageType":
        ApiInfo("POST", "/", {"Action": "GetPrivateImageType", "Version": IMAGEX_API_VERSION}, {}, {}),
    "CreateImageHmEmbed":
        ApiInfo("POST", "/", {"Action": "CreateImageHmEmbed", "Version": IMAGEX_API_VERSION}, {}, {}),
    "CreateImageHmExtract":
        ApiInfo("POST", "/", {"Action": "CreateImageHmExtract", "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageEraseResult":
        ApiInfo("POST", "/", {"Action": "GetImageEraseResult", "Version": IMAGEX_API_VERSION}, {}, {}),
}



# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo


class IamService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(IamService, "_instance"):
            with IamService._instance_lock:
                if not hasattr(IamService, "_instance"):
                    IamService._instance = object.__new__(cls)
        return IamService._instance

    def __init__(self):
        self.service_info = IamService.get_service_info()
        self.api_info = IamService.get_api_info()
        super(IamService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("iam.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'iam', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            # Access Key
            "CreateAccessKey": ApiInfo("GET", "/", {"Action": "CreateAccessKey", "Version": "2018-01-01"}, {}, {}),
            "DeleteAccessKey": ApiInfo("GET", "/", {"Action": "DeleteAccessKey", "Version": "2018-01-01"}, {}, {}),
            "ListAccessKeys": ApiInfo("GET", "/", {"Action": "ListAccessKeys", "Version": "2018-01-01"}, {}, {}),
            "UpdateAccessKey": ApiInfo("GET", "/", {"Action": "UpdateAccessKey", "Version": "2018-01-01"}, {}, {}),
            # User
            "CreateUser": ApiInfo("GET", "/", {"Action": "CreateUser", "Version": "2018-01-01"}, {}, {}),
            "GetUser": ApiInfo("GET", "/", {"Action": "GetUser", "Version": "2018-01-01"}, {}, {}),
            "UpdateUser": ApiInfo("GET", "/", {"Action": "UpdateUser", "Version": "2018-01-01"}, {}, {}),
            "ListUsers": ApiInfo("GET", "/", {"Action": "ListUsers", "Version": "2018-01-01"}, {}, {}),
            "DeleteUser": ApiInfo("GET", "/", {"Action": "DeleteUser", "Version": "2018-01-01"}, {}, {}),
            "CreateLoginProfile": ApiInfo("GET", "/", {"Action": "CreateLoginProfile", "Version": "2018-01-01"}, {}, {}),
            "GetLoginProfile": ApiInfo("GET", "/", {"Action": "GetLoginProfile", "Version": "2018-01-01"}, {}, {}),
            "UpdateLoginProfile": ApiInfo("GET", "/", {"Action": "UpdateLoginProfile", "Version": "2018-01-01"}, {}, {}),
            "DeleteLoginProfile": ApiInfo("GET", "/", {"Action": "DeleteLoginProfile", "Version": "2018-01-01"}, {}, {}),
            # Role
            "CreateRole": ApiInfo("GET", "/", {"Action": "CreateRole", "Version": "2018-01-01"}, {}, {}),
            "GetRole": ApiInfo("GET", "/", {"Action": "GetRole", "Version": "2018-01-01"}, {}, {}),
            "UpdateRole": ApiInfo("GET", "/", {"Action": "UpdateRole", "Version": "2018-01-01"}, {}, {}),
            "ListRoles": ApiInfo("GET", "/", {"Action": "ListRoles", "Version": "2018-01-01"}, {}, {}),
            "DeleteRole": ApiInfo("GET", "/", {"Action": "DeleteRole", "Version": "2018-01-01"}, {}, {}),
            "CreateServiceLinkedRole": ApiInfo("GET", "/", {"Action": "CreateServiceLinkedRole", "Version": "2018-01-01"}, {}, {}),
            # Identity Provider
            "CreateSAMLProvider": ApiInfo("POST", "/", {"Action": "CreateSAMLProvider", "Version": "2018-01-01"}, {}, {}),
            "GetSAMLProvider": ApiInfo("GET", "/", {"Action": "GetSAMLProvider", "Version": "2018-01-01"}, {}, {}),
            "UpdateSAMLProvider": ApiInfo("POST", "/", {"Action": "UpdateSAMLProvider", "Version": "2018-01-01"}, {}, {}),
            "ListSAMLProviders": ApiInfo("GET", "/", {"Action": "ListSAMLProviders", "Version": "2018-01-01"}, {}, {}),
            "DeleteSAMLProvider": ApiInfo("GET", "/", {"Action": "DeleteSAMLProvider", "Version": "2018-01-01"}, {}, {}),
            # Policy
            "CreatePolicy": ApiInfo("GET", "/", {"Action": "CreatePolicy", "Version": "2018-01-01"}, {}, {}),
            "GetPolicy": ApiInfo("GET", "/", {"Action": "GetPolicy", "Version": "2018-01-01"}, {}, {}),
            "ListPolicies": ApiInfo("GET", "/", {"Action": "ListPolicies", "Version": "2018-01-01"}, {}, {}),
            "UpdatePolicy": ApiInfo("GET", "/", {"Action": "UpdatePolicy", "Version": "2018-01-01"}, {}, {}),
            "DeletePolicy": ApiInfo("GET", "/", {"Action": "DeletePolicy", "Version": "2018-01-01"}, {}, {}),
            "AttachUserPolicy": ApiInfo("GET", "/", {"Action": "AttachUserPolicy", "Version": "2018-01-01"}, {}, {}),
            "DetachUserPolicy": ApiInfo("GET", "/", {"Action": "DetachUserPolicy", "Version": "2018-01-01"}, {}, {}),
            "ListAttachedUserPolicies": ApiInfo("GET", "/", {"Action": "ListAttachedUserPolicies", "Version": "2018-01-01"}, {}, {}),
            "AttachRolePolicy": ApiInfo("GET", "/", {"Action": "AttachRolePolicy", "Version": "2018-01-01"}, {}, {}),
            "DetachRolePolicy": ApiInfo("GET", "/", {"Action": "DetachRolePolicy", "Version": "2018-01-01"}, {}, {}),
            "ListAttachedRolePolicies": ApiInfo("GET", "/", {"Action": "ListAttachedRolePolicies", "Version": "2018-01-01"}, {}, {}),
            "ListEntitiesForPolicy": ApiInfo("GET", "/", {"Action": "ListEntitiesForPolicy", "Version": "2018-01-01"}, {}, {}),
        }
        return api_info

    # Access Key

    def create_access_key(self, params):
        res = self.get("CreateAccessKey", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def delete_access_key(self, params):
        res = self.get("DeleteAccessKey", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_access_keys(self, params):
        res = self.get("ListAccessKeys", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def update_access_key(self, params):
        res = self.get("UpdateAccessKey", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    # User

    def create_user(self, params):
        res = self.get("CreateUser", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def get_user(self, params):
        res = self.get("GetUser", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def update_user(self, params):
        res = self.get("UpdateUser", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_users(self, params):
        res = self.get("ListUsers", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json
    
    def delete_user(self, params):
        res = self.get("DeleteUser", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def create_login_profile(self, params):
        res = self.get("CreateLoginProfile", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def get_login_profile(self, params):
        res = self.get("GetLoginProfile", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def update_login_profile(self, params):
        res = self.get("UpdateLoginProfile", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def delete_login_profile(self, params):
        res = self.get("DeleteLoginProfile", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    # Role

    def create_role(self, params):
        res = self.get("CreateRole", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def get_role(self, params):
        res = self.get("GetRole", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def update_role(self, params):
        res = self.get("UpdateRole", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_roles(self, params):
        res = self.get("ListRoles", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def delete_role(self, params):
        res = self.get("DeleteRole", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json
    
    def create_service_linked_role(self, params):
        res = self.get("CreateServiceLinkedRole", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    # Identity Provider

    def create_saml_provider(self, params):
        res = self.post("CreateSAMLProvider", {}, params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def get_saml_provider(self, params):
        res = self.get("GetSAMLProvider", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def update_saml_provider(self, params):
        res = self.post("UpdateSAMLProvider", {}, params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_saml_providers(self, params):
        res = self.get("ListSAMLProviders", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def delete_saml_provider(self, params):
        res = self.get("DeleteSAMLProvider", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    # Policy

    def create_policy(self, params):
        res = self.get("CreatePolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def get_policy(self, params):
        res = self.get("GetPolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_policies(self, params):
        res = self.get("ListPolicies", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def update_policy(self, params):
        res = self.get("UpdatePolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def delete_policy(self, params):
        res = self.get("DeletePolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def attach_user_policy(self, params):
        res = self.get("AttachUserPolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def detach_user_policy(self, params):
        res = self.get("DetachUserPolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_attached_user_policies(self, params):
        res = self.get("ListAttachedUserPolicies", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def attach_role_policy(self, params):
        res = self.get("AttachRolePolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def detach_role_policy(self, params):
        res = self.get("DetachRolePolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_attached_role_policies(self, params):
        res = self.get("ListAttachedRolePolicies", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_entities_for_policy(self, params):
        res = self.get("ListEntitiesForPolicy", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    bind_axb_for_axne_form = {
        "NumberPoolNo": "NP167091951102821491",
        "ParentSubId": "S16729859759534216e440",
        "PhoneNoB": "13500000001",
        "EnableDuration": 360, 
    }
    print(secretNumberService.bind_axb_for_axne(bind_axb_for_axne_form))



# coding:utf-8
from __future__ import print_function

from volcengine.visual.VisualService import VisualService

if __name__ == '__main__':
    visual_service = VisualService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    visual_service.set_ak('ak')
    visual_service.set_sk('sk')
    # visual_service.set_host('host')
    action = ""
    version = ""
    visual_service.set_api_info(action, version)

    # below shows the sdk usage for all common apis,
    # if you cannot find the needed one, please check other example files in the same dir
    # or contact us for further help
    form = dict()
    form["image_base64"] = "image_base64_str"
    resp = visual_service.ocr_api(action, form)
    
    
    # 通用识别
    # 通用OCR       
    # action=OCRNormal, version=2020-08-26
    # 多语种OCR     
    # action=MultiLanguageOCR, version=2022-08-31

    # 个人卡证
    # 银行卡OCR     
    # action=BankCard, version=2020-08-26
    # 身份证OCR     
    # action=IDCard, version=2020-08-26
    # 驾驶证OCR     
    # action=DrivingLicense, version=2020-08-26
    # 行驶证OCR     
    # action=VehicleLicense, version=2020-08-26
    # 台胞证        
    # action=OcrTaibao, version=2021-08-23

    # 财务票据
    # 混贴报销      
    # action=OcrFinance, version=2021-08-23
    # 出租车票OCR   
    # action=OcrTaxiInvoice, version=2020-08-26
    # 火车票OCR     
    # action=OcrTrainTicket, version=2020-08-26
    # 行程单OCR     
    # action=OcrFlightInvoice, version=2020-08-26
    # 增值税发票OCR 
    # action=OcrVatInvoice, version=2020-08-26
    # 定额发票OCR   
    # action=OcrQuotaInvoice, version=2020-08-26
    # 高速公路过路费 
    # action=OcrPassInvoice, version=2021-08-23
    
    # 资质证书
    # 食品生产许可证 
    # action=OcrFoodProduction, version=2021-08-23
    # 食品经营许可证 
    # action=OcrFoodBusiness, version=2020-08-26
    # 营业执照OCR   
    # action=OcrClueLicense, version=2020-08-26
    # 商标证        
    # action=OCRTrade, version=2020-12-21
    # 软件著作权    
    # action=OCRRuanzhu, version=2020-12-21
    # 化妆品生产许可证  
    # action=OCRCosmeticProduct, version=2020-12-21

    # 行业文档
    # 印章识别      
    # action=OcrSeal, version=2021-08-23
    # 合同校验      
    # action=OcrTextAlignment, version=2021-08-23
    # pdf识别       
    # action=OCRPdf, version=2021-08-23
    # 表格识别      
    # action=OCRTable, version=2021-08-23
    print(resp)


# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.live_requests import UpdatePullToPushTaskRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')

    req = UpdatePullToPushTaskRequest()
    req.Title = ''
    req.Type = 1
    req.CycleMode = -1
    req.StartTime = 0
    req.EndTime = 0
    req.TaskId = ''
    req.DstAddr = ''
    req.SrcAddr = ''
    req.SrcAddrS = []
    req.SrcAddrS.extend([''])

    print(req)
    resp = live_service.update_pull_to_push_task(req)
    print(resp)


# coding:utf-8
import json

from volcengine.live.LiveService import LiveService

if __name__ == '__main__':
    live_service = LiveService()
    ak = ""
    sk = ""
    live_service.set_ak(ak)
    live_service.set_sk(sk)
    body = {
        "Domain": "",
        "App": "",
        "RefererInfoList":
            [
                {
                    "Key": "asd",
                    "Type": "xx",
                    "Value": "sad",
                    "Priority": 0,
                },
            ]
    }
    resp = live_service.update_referer(body)
    print(resp)



# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo
from volcengine.const.Const import *
from retry import retry


class SmsService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(SmsService, "_instance"):
            with SmsService._instance_lock:
                if not hasattr(SmsService, "_instance"):
                    SmsService._instance = object.__new__(cls)
        return SmsService._instance

    def __init__(self, region=REGION_CN_NORTH1):
        self.service_info = SmsService.get_service_info(self, region)
        self.api_info = SmsService.get_api_info()
        super(SmsService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(self, region):
        if region == REGION_AP_SINGAPORE1:
            service_info = ServiceInfo("sms.byteplusapi.com", {'Accept': 'application/json'},
                                       Credentials('', '', 'volcSMS', region), 5, 5)
        else:
            service_info = ServiceInfo("sms.volcengineapi.com", {'Accept': 'application/json'},
                                       Credentials('', '', 'volcSMS', region), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "SendSms": ApiInfo("POST", "/", {"Action": "SendSms", "Version": "2020-01-01"}, {}, {}),
            "SendSmsVerifyCode": ApiInfo("POST", "/", {"Action": "SendSmsVerifyCode", "Version": "2020-01-01"}, {}, {}),
            "CheckSmsVerifyCode": ApiInfo("POST", "/", {"Action": "CheckSmsVerifyCode", "Version": "2020-01-01"}, {},
                                          {}),
            "SendBatchSms": ApiInfo("POST", "/", {"Action": "SendBatchSms", "Version": "2021-01-01"}, {}, {}),
            "Conversion": ApiInfo("POST", "/", {"Action": "Conversion", "Version": "2020-01-01"}, {}, {}),
            "GetSmsTemplateAndOrderList": ApiInfo("GET", "/",
                                                  {"Action": "GetSmsTemplateAndOrderList", "Version": "2021-01-11"}, {},
                                                  {}),
            "ApplySmsTemplate": ApiInfo("POST", "/", {"Action": "ApplySmsTemplate", "Version": "2021-01-11"}, {}, {}),
            "DeleteSmsTemplate": ApiInfo("POST", "/", {"Action": "DeleteSmsTemplate", "Version": "2021-01-11"}, {}, {}),
            "GetSubAccountList": ApiInfo("GET", "/", {"Action": "GetSubAccountList", "Version": "2021-01-11"}, {}, {}),
            "GetSubAccountDetail": ApiInfo("GET", "/", {"Action": "GetSubAccountDetail", "Version": "2021-01-11"}, {},
                                           {}),
            "GetSignatureAndOrderList": ApiInfo("GET", "/",
                                                {"Action": "GetSignatureAndOrderList", "Version": "2021-01-11"}, {},
                                                {}),
            "ApplySmsSignature": ApiInfo("POST", "/", {"Action": "ApplySmsSignature", "Version": "2021-01-11"}, {}, {}),
            "DeleteSignature": ApiInfo("POST", "/", {"Action": "DeleteSignature", "Version": "2021-01-11"}, {},
                                       {}),
            "ApplyVmsTemplate": ApiInfo("POST", "/", {"Action": "ApplyVmsTemplate", "Version": "2021-01-11"}, {},
                                        {}),
            "GetVmsTemplateStatus": ApiInfo("POST", "/", {"Action": "GetVmsTemplateStatus", "Version": "2021-01-11"},
                                            {},
                                            {}),
        }
        return api_info

    @retry(tries=2, delay=0)
    def send_sms(self, body):
        res = self.json('SendSms', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def send_sms_verify_code(self, body):
        res = self.json('SendSmsVerifyCode', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def check_sms_verify_code(self, body):
        res = self.json('CheckSmsVerifyCode', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def send_batch_sms(self, body):
        res = self.json('SendBatchSms', {}, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def conversion(self, body):
        res = self.json('Conversion', {}, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def get_sms_template_and_order_list(self, param):
        res = self.get('GetSmsTemplateAndOrderList', param)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def apply_sms_template(self, body):
        res = self.json('ApplySmsTemplate', {}, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def delete_sms_template(self, body):
        res = self.post('DeleteSmsTemplate', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def get_sub_account_list(self, param):
        res = self.get('GetSubAccountList', param)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def get_sub_account_detail(self, param):
        res = self.get('GetSubAccountDetail', param)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def get_signature_and_order_list(self, param):
        res = self.get('GetSignatureAndOrderList', param)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def apply_sms_signature(self, body):
        res = self.json('ApplySmsSignature', {}, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def delete_signature(self, body):
        res = self.json('DeleteSignature', {}, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def apply_vms_template(self, body):
        body["caller"] = "sdk"
        if body["channelType"] is None or body["channelType"] == "":
            body["channelType"] = "CN_VMS"
        res = self.json('ApplyVmsTemplate', {}, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        if 'Result' in res_json.keys() and 'templateId' in res_json['Result'].keys():
            res_json['Result'] = {
                "templateId": res_json['Result']["templateId"]}
        return res_json

    @retry(tries=2, delay=0)
    def get_vms_template_status(self, body):
        res = self.json('GetVmsTemplateStatus', {}, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    @retry(tries=2, delay=0)
    def send_vms(self, body):
        res = self.json('SendSms', {}, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json



# coding:utf-8
from __future__ import print_function

import json

from volcengine.const.Const import REGION_AP_SINGAPORE1
from volcengine.sms.SmsService import SmsService

if __name__ == '__main__':
    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)
    # cn
    sms_service = SmsService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_scheme("http")
    # sms_service.set_scheme("https")
    # sms_service.set_host('host')¬

    body = {
        "subAccount": "subAccount",
        "id": "id",
        "isOrder": True
    }

    resp = sms_service.delete_sms_template(body)
    print(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/addr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18live/business/addr.proto\x12\x1fVolcengine.Live.Models.Business\"R\n\x15GeneratePlayURLResult\x12\x39\n\x07URLList\x18\x01 \x03(\x0b\x32(.Volcengine.Live.Models.Business.PlayURL\"C\n\x07PlayURL\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x0b\n\x03\x43\x44N\x18\x02 \x01(\t\x12\x10\n\x08Protocol\x18\x03 \x01(\t\x12\x0c\n\x04Type\x18\x04 \x01(\t\"\xbf\x01\n\x15GeneratePushURLResult\x12\x13\n\x0bPushURLList\x18\x01 \x03(\t\x12G\n\x11PushURLListDetail\x18\x02 \x03(\x0b\x32,.Volcengine.Live.Models.Business.PushURLItem\x12\x18\n\x10TsOverSrtURLList\x18\x03 \x03(\t\x12\x1a\n\x12RtmpOverSrtURLList\x18\x04 \x03(\t\x12\x12\n\nRtmURLList\x18\x05 \x03(\t\"A\n\x0bPushURLItem\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x11\n\tDomainApp\x18\x02 \x01(\t\x12\x12\n\nStreamSign\x18\x03 \x01(\tB\xcc\x01\n*com.volcengine.service.live.model.businessB\x04\x41\x64\x64rP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_GENERATEPLAYURLRESULT = DESCRIPTOR.message_types_by_name['GeneratePlayURLResult']
_PLAYURL = DESCRIPTOR.message_types_by_name['PlayURL']
_GENERATEPUSHURLRESULT = DESCRIPTOR.message_types_by_name['GeneratePushURLResult']
_PUSHURLITEM = DESCRIPTOR.message_types_by_name['PushURLItem']
GeneratePlayURLResult = _reflection.GeneratedProtocolMessageType('GeneratePlayURLResult', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEPLAYURLRESULT,
  '__module__' : 'live.business.addr_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.GeneratePlayURLResult)
  })
_sym_db.RegisterMessage(GeneratePlayURLResult)

PlayURL = _reflection.GeneratedProtocolMessageType('PlayURL', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURL,
  '__module__' : 'live.business.addr_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.PlayURL)
  })
_sym_db.RegisterMessage(PlayURL)

GeneratePushURLResult = _reflection.GeneratedProtocolMessageType('GeneratePushURLResult', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEPUSHURLRESULT,
  '__module__' : 'live.business.addr_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.GeneratePushURLResult)
  })
_sym_db.RegisterMessage(GeneratePushURLResult)

PushURLItem = _reflection.GeneratedProtocolMessageType('PushURLItem', (_message.Message,), {
  'DESCRIPTOR' : _PUSHURLITEM,
  '__module__' : 'live.business.addr_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.PushURLItem)
  })
_sym_db.RegisterMessage(PushURLItem)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\004AddrP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _GENERATEPLAYURLRESULT._serialized_start=61
  _GENERATEPLAYURLRESULT._serialized_end=143
  _PLAYURL._serialized_start=145
  _PLAYURL._serialized_end=212
  _GENERATEPUSHURLRESULT._serialized_start=215
  _GENERATEPUSHURLRESULT._serialized_end=406
  _PUSHURLITEM._serialized_start=408
  _PUSHURLITEM._serialized_end=473
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from __future__ import print_function

import json

from volcengine.emr.EMRService import EMRService

if __name__ == '__main__':
    emr_service = EMRService(region="cn-beijing")

    # call the following methods explicitly if you dont set ak and sk in $HOME/.volc/config
    # emr_service.set_ak(testAk)
    # emr_service.set_sk(testSk)

    params = {}
    resp = emr_service.list_clusters(params)
    print(json.dumps(resp, ensure_ascii=False, sort_keys=True, indent=4, separators=(',', ':')))



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    bind_axyb_form = {
        "NumberPoolNo": "NP166375725010908111",
        "PhoneNoA": "13700000017",
        "CityCode": "010",
        "UserData": "this is my user data",
        "ExpireTime": "1673071556",
        "YbEnableDuration": 600,
        "NumberPoolNoY": "NP166265127202826653"
    }
    print(secretNumberService.bind_axyb(bind_axyb_form))



# coding:utf-8
from __future__ import print_function

import json

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodGetDirectEditProgressRequest

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('ak')
    vod_service.set_sk('sk')
    req = VodGetDirectEditProgressRequest()
    req.ReqId = 'your ReqId'
    resp = vod_service.get_direct_edit_progress(req)
    l = json.loads(resp)
    print(json.dumps(l, ensure_ascii=False, indent=4))
    print("****")



#  -*- coding: utf-8 -*-
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo

service_info_map = {
    "cn-beijing": ServiceInfo("open.volcengineapi.com", {'accept': 'application/json', },
                              Credentials('', '', "emr", "cn-beijing"), 60 * 5, 60 * 5, "https"),
    "cn-guangzhou": ServiceInfo("open.volcengineapi.com", {'accept': 'application/json', },
                                Credentials('', '', "emr", "cn-guangzhou"), 60 * 5, 60 * 5, "https"),
    "cn-shanghai": ServiceInfo("open.volcengineapi.com", {'accept': 'application/json', },
                               Credentials('', '', "emr", "cn-shanghai"), 60 * 5, 60 * 5, "https"),
}

api_info = {
    # https://www.volcengine.com/docs/6491/145561
    "CreateCluster": ApiInfo("POST", "/", {
        "Action": "CreateCluster", "Version": "2022-06-30"}, {}, {}),
    # https://www.volcengine.com/docs/6491/145562
    "ResizeCluster": ApiInfo("GET", "/", {
        "Action": "ResizeCluster", "Version": "2022-04-15"}, {}, {}),

    # https://www.volcengine.com/docs/6491/145563
    "DescribeCluster": ApiInfo("GET", "/", {
        "Action": "DescribeCluster", "Version": "2022-04-15"}, {}, {}),

    # https://www.volcengine.com/docs/6491/145564
    "ListInstances": ApiInfo("GET", "/", {
        "Action": "ListInstances", "Version": "2022-06-30"}, {}, {}),

    # https://www.volcengine.com/docs/6491/145565
    "ListClusters": ApiInfo("GET", "/", {
        "Action": "ListClusters", "Version": "2021-09-15"}, {}, {}),

    # https://www.volcengine.com/docs/6491/145566
    "ListInstanceGroups": ApiInfo("POST", "/", {
        "Action": "ListInstanceGroups", "Version": "2022-06-30"}, {}, {}),

    # https://www.volcengine.com/docs/6491/145567
    "ReleaseCluster": ApiInfo("POST", "/", {
        "Action": "ReleaseCluster", "Version": "2022-04-15"}, {}, {}),

    # https://www.volcengine.com/docs/6491/145568
    "AddTags": ApiInfo("POST", "/", {
        "Action": "AddTags", "Version": "2022-06-30"}, {}, {}),

    # https://www.volcengine.com/docs/6491/145569
    "RemoveTags": ApiInfo("POST", "/", {
        "Action": "RemoveTags", "Version": "2022-06-30"}, {}, {}),
}


class EMRService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(EMRService, "_instance"):
            with EMRService._instance_lock:
                if not hasattr(EMRService, "_instance"):
                    EMRService._instance = object.__new__(cls)
        return EMRService._instance

    def __init__(self, region="cn-beijing"):
        self.service_info = EMRService.get_service_info(region)
        self.api_info = EMRService.get_api_info()
        super(EMRService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('do not support region %s' % region)
        return service_info

    @staticmethod
    def get_api_info():
        return api_info

    def create_cluster(self, params, body):
        res = self.json("CreateCluster", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def describe_cluster(self, params):
        res = self.get("DescribeCluster", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_instances(self, params):
        res = self.get("ListInstances", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_clusters(self, params):
        res = self.get("ListClusters", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def list_instance_groups(self, params, body):
        res = self.json("ListInstanceGroups", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def release_cluster(self, params, body):
        res = self.json("ReleaseCluster", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def add_tags(self, params, body):
        res = self.json("AddTags", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def remove_tags(self, params, body):
        res = self.json("RemoveTags", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json



# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodGetPrivateDrmPlayAuthRequest

if __name__ == '__main__':

    vod_service = VodService()
    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')
    try:
        vid = 'your vid'
        req = VodGetPrivateDrmPlayAuthRequest()
        req.Vid = vid
        req.DrmType = 'your drm type'
        req.PlayAuthIds = 'a,b,c (your PlayAuthIds)'
        req.UnionInfo = 'your unionInfo'
        resp = vod_service.get_private_drm_play_auth(req)
    except Exception:
        raise
    else:
        print(resp)
    print('*' * 100)



# coding:utf-8
import json

from volcengine.imagex.ImageXService import ImageXService


def describe_imagex_domain_traffic_data(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXDomainTrafficData', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXDomainTrafficData')
    res_json = json.loads(res)
    return res_json


def describe_imagex_domain_bandwidth_data(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXDomainBandwidthData', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXDomainBandwidthData')
    res_json = json.loads(res)
    return res_json


def describe_imagex_bucket_usage(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXBucketUsage', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXBucketUsage')
    res_json = json.loads(res)
    return res_json


def describe_imagex_request_cnt_usage(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXRequestCntUsage', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXRequestCntUsage')
    res_json = json.loads(res)
    return res_json


def describe_imagex_base_op_usage(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXBaseOpUsage', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXBaseOpUsage')
    res_json = json.loads(res)
    return res_json


def describe_imagex_compress_usage(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXCompressUsage', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXCompressUsage')
    res_json = json.loads(res)
    return res_json


def describe_imagex_edge_request(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXEdgeRequest', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXEdgeRequest')
    res_json = json.loads(res)
    return res_json


def describe_imagex_hit_rate_traffic_data(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXHitRateTrafficData', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXHitRateTrafficData')
    res_json = json.loads(res)
    return res_json


def describe_imagex_hit_rate_request_data(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXHitRateRequestData', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXHitRateRequestData')
    res_json = json.loads(res)
    return res_json


def describe_imagex_cdntop_request_data(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXCDNTopRequestData', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXCDNTopRequestData')
    res_json = json.loads(res)
    return res_json


def describe_imagex_summary(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXSummary', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXSummary')
    res_json = json.loads(res)
    return res_json


def describe_imagex_edge_request_bandwidth(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXEdgeRequestBandwidth', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXEdgeRequestBandwidth')
    res_json = json.loads(res)
    return res_json


def describe_imagex_edge_request_traffic(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXEdgeRequestTraffic', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXEdgeRequestTraffic')
    res_json = json.loads(res)
    return res_json


def describe_imagex_edge_request_regions(service: ImageXService, query):
    res = service.imagex_get('DescribeImageXEdgeRequestRegions', query)
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXEdgeRequestRegions')
    res_json = json.loads(res)
    return res_json


def describe_imagex_mirror_request_traffic(service: ImageXService, body):
    res = service.imagex_post('DescribeImageXMirrorRequestTraffic', [], json.dumps(body))
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXMirrorRequestTraffic')
    res_json = json.loads(res)
    return res_json


def describe_imagex_mirror_request_bandwidth(service: ImageXService, body):
    res = service.imagex_post('DescribeImageXMirrorRequestBandwidth', [], json.dumps(body))
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXMirrorRequestBandwidth')
    res_json = json.loads(res)
    return res_json


def describe_imagex_mirror_request_http_code_by_time(service: ImageXService, body):
    res = service.imagex_post('DescribeImageXMirrorRequestHttpCodeByTime', [], json.dumps(body))
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXMirrorRequestHttpCodeByTime')
    res_json = json.loads(res)
    return res_json


def describe_imagex_mirror_request_http_code_overview(service: ImageXService, body):
    res = service.imagex_post('DescribeImageXMirrorRequestHttpCodeOverview', [], json.dumps(body))
    if res == '':
        raise Exception("%s: empty response" % 'DescribeImageXMirrorRequestHttpCodeOverview')
    res_json = json.loads(res)
    return res_json



#  -*- coding: utf-8 -*-
import os
import sys

sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../../")

from volcengine.example.dcdn import ak, sk
from volcengine.dcdn.DCDNService import DCDNService

if __name__ == '__main__':
    svc = DCDNService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    svc.set_ak(ak)
    svc.set_sk(sk)

    params = {
        "StartTime": "2022-08-09 00:00:00",
        "EndTime": "2022-08-09 00:20:11",
        "Domains": [
            "www.test1.com",
            "www.test2.com"
        ],
        "Metrics": [
            "all"
        ],
        "Interval": 300
    }

    resp = svc.describe_origin_statistics_detail(params)
    print(resp)



# coding:utf-8
from __future__ import print_function

from volcengine.bioos.BioOsService import BioOsService

if __name__ == '__main__':
    # set endpoint/region here if the default value is unsatisfied
    bioos_service = BioOsService(endpoint='endpoint', region='region')

    # call below method if you don't set ak and sk in $HOME/.volc/config
    bioos_service.set_ak('ak')
    bioos_service.set_sk('sk')

    params = {
        'PageNumber': 1,
        'PageSize': 10,
        'Filter': {
            'IDs': ['test-workflow'],
            'Status': ['Running'],
            'Type': ['shared'],
            'Public': True,
        },
    }

    resp = bioos_service.list_clusters(params)
    print(resp)



#  -*- coding: utf-8 -*-
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo

SERVICE_VERSION = "2021-04-01"

service_info = ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                           Credentials('', '', 'dcdn', 'cn-north-1'), 60 * 5, 60 * 5, "https")

api_info = {
    # 查询域名列表: https://www.volcengine.com/docs/6559/95182
    "DescribeUserDomains": ApiInfo("GET", "/", {
        "Action": "DescribeUserDomains", "Version": SERVICE_VERSION}, {}, {}),

    # 查询全站加速域名的详细配置: https://www.volcengine.com/docs/6559/94321
    "DescribeDomainConfig": ApiInfo("POST", "/", {
        "Action": "DescribeDomainConfig", "Version": SERVICE_VERSION}, {}, {}),

    # 新增全站加速域名: https://www.volcengine.com/docs/6559/79725
    "CreateDomain": ApiInfo("POST", "/", {
        "Action": "CreateDomain", "Version": SERVICE_VERSION}, {}, {}),

    # 启动全站加速域名: https://www.volcengine.com/docs/6559/94320
    "StartDomain": ApiInfo("POST", "/", {
        "Action": "StartDomain", "Version": SERVICE_VERSION}, {}, {}),

    # 停止全站加速域名: https://www.volcengine.com/docs/6559/94319
    "StopDomain": ApiInfo("POST", "/", {
        "Action": "StopDomain", "Version": SERVICE_VERSION}, {}, {}),

    # 删除全站加速域名: https://www.volcengine.com/docs/6559/95181
    "DeleteDomain": ApiInfo("POST", "/", {
        "Action": "DeleteDomain", "Version": SERVICE_VERSION}, {}, {}),

    # 变更域名配置: https://www.volcengine.com/docs/6559/95183
    "UpdateDomainConfig": ApiInfo("POST", "/", {
        "Action": "UpdateDomainConfig", "Version": SERVICE_VERSION}, {}, {}),

    # 查询域名的资源用量数据: https://www.volcengine.com/docs/6559/79733
    "DescribeStatistics": ApiInfo("POST", "/", {
        "Action": "DescribeStatistics", "Version": SERVICE_VERSION}, {}, {}),

    # 查询域名的回源资源用量数据: https://www.volcengine.com/docs/6559/79734
    "DescribeOriginStatistics": ApiInfo("POST", "/", {
        "Action": "DescribeOriginStatistics", "Version": SERVICE_VERSION}, {}, {}),

    # 查询域名的实时资源用量数据: https://www.volcengine.com/docs/6559/79735
    "DescribeRealtimeData": ApiInfo("POST", "/", {
        "Action": "DescribeRealtimeData", "Version": SERVICE_VERSION}, {}, {}),

    # 查询域名的回源实时资源用量数据: https://www.volcengine.com/docs/6559/79737
    "DescribeOriginRealtimeData": ApiInfo("POST", "/", {
        "Action": "DescribeOriginRealtimeData", "Version": SERVICE_VERSION}, {}, {}),

    # 统计域名的区域分布数据: https://www.volcengine.com/docs/6559/79738
    "DescribeDomainRegionData": ApiInfo("POST", "/", {
        "Action": "DescribeDomainRegionData", "Version": SERVICE_VERSION}, {}, {}),

    # 统计域名的运营商分布数据: https://www.volcengine.com/docs/6559/79739
    "DescribeDomainIspData": ApiInfo("POST", "/", {
        "Action": "DescribeDomainIspData", "Version": SERVICE_VERSION}, {}, {}),

    # 统计域名的排行数据: https://www.volcengine.com/docs/6559/79740
    "DescribeTopDomains": ApiInfo("POST", "/", {
        "Action": "DescribeTopDomains", "Version": SERVICE_VERSION}, {}, {}),

    # 统计URL的排行数据: https://www.volcengine.com/docs/6559/79741
    "DescribeTopURLs": ApiInfo("POST", "/", {
        "Action": "DescribeTopURLs", "Version": SERVICE_VERSION}, {}, {}),

    # 统计IP的排行数据: https://www.volcengine.com/docs/6559/79742
    "DescribeTopIPs": ApiInfo("POST", "/", {
        "Action": "DescribeTopIPs", "Version": SERVICE_VERSION}, {}, {}),

    # 统计Referer的排行数据: https://www.volcengine.com/docs/6559/79743
    "DescribeTopReferers": ApiInfo("POST", "/", {
        "Action": "DescribeTopReferers", "Version": SERVICE_VERSION}, {}, {}),

    # 查询域名的PV数据: https://www.volcengine.com/docs/6559/79747
    "DescribeDomainPVData": ApiInfo("POST", "/", {
        "Action": "DescribeDomainPVData", "Version": SERVICE_VERSION}, {}, {}),

    # 查询域名的UV数据: https://www.volcengine.com/docs/6559/79749
    "DescribeDomainUVData": ApiInfo("POST", "/", {
        "Action": "DescribeDomainUVData", "Version": SERVICE_VERSION}, {}, {}),

    # 查询地域和运营商信息: https://www.volcengine.com/docs/6559/126042
    "DescribeDcdnRegionAndIsp": ApiInfo("GET", "/", {
        "Action": "DescribeDcdnRegionAndIsp", "Version": SERVICE_VERSION}, {}, {}),

    # 查询访问资源用量细节: https://www.volcengine.com/docs/6559/131240
    "DescribeStatisticsDetail": ApiInfo("POST", "/", {
        "Action": "DescribeStatisticsDetail", "Version": SERVICE_VERSION}, {}, {}),

    # 查询访问回源资源用量细节: https://www.volcengine.com/docs/6559/131253
    "DescribeOriginStatisticsDetail": ApiInfo("POST", "/", {
        "Action": "DescribeOriginStatisticsDetail", "Version": SERVICE_VERSION}, {}, {}),

    # 查询访问日志: https://www.volcengine.com/docs/6559/79745
    "DescribeDomainLogs": ApiInfo("POST", "/", {
        "Action": "DescribeDomainLogs", "Version": SERVICE_VERSION}, {}, {}),

    # 新增全站加速预热刷新任务: https://www.volcengine.com/docs/6559/102400
    "CreatePurgePrefetchTask": ApiInfo("POST", "/", {
        "Action": "CreatePurgePrefetchTask", "Version": SERVICE_VERSION}, {}, {}),

    # 查询全站加速预热刷新任务: https://www.volcengine.com/docs/6559/102401
    "CheckPurgePrefetchTask": ApiInfo("POST", "/", {
        "Action": "CheckPurgePrefetchTask", "Version": SERVICE_VERSION}, {}, {}),

    # 查询全站加速预热刷新任务Quota: https://www.volcengine.com/docs/6559/102402
    "GetPurgePrefetchTaskQuota": ApiInfo("GET", "/", {
        "Action": "GetPurgePrefetchTaskQuota", "Version": SERVICE_VERSION}, {}, {}),

    # 查询全站加速预热刷新任务Quota: https://www.volcengine.com/docs/6559/102403
    "RetryPurgePrefetchTask": ApiInfo("POST", "/", {
        "Action": "RetryPurgePrefetchTask", "Version": SERVICE_VERSION}, {}, {}),
}


class DCDNService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(DCDNService, "_instance"):
            with DCDNService._instance_lock:
                if not hasattr(DCDNService, "_instance"):
                    DCDNService._instance = object.__new__(cls)
        return DCDNService._instance

    def __init__(self):
        self.service_info = DCDNService.get_service_info()
        self.api_info = DCDNService.get_api_info()
        super(DCDNService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        return service_info

    @staticmethod
    def get_api_info():
        return api_info

    def describe_user_domains(self, params=None):
        if params is None:
            params = {}
        action = "DescribeUserDomains"
        res = self.get(action, params)
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_domain_config(self, params=None):
        if params is None:
            params = {}
        action = "DescribeDomainConfig"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def create_domain(self, params=None):
        if params is None:
            params = {}
        action = "CreateDomain"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def start_domain(self, params=None):
        if params is None:
            params = {}
        action = "StartDomain"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def stop_domain(self, params=None):
        if params is None:
            params = {}
        action = "StopDomain"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def delete_domain(self, params=None):
        if params is None:
            params = {}
        action = "DeleteDomain"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def update_domain_config(self, params=None):
        if params is None:
            params = {}
        action = "UpdateDomainConfig"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_statistics(self, params=None):
        if params is None:
            params = {}
        action = "DescribeStatistics"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_origin_statistics(self, params=None):
        if params is None:
            params = {}
        action = "DescribeOriginStatistics"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_realtime_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeRealtimeData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_origin_realtime_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeOriginRealtimeData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_domain_region_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeDomainRegionData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_domain_isp_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeDomainIspData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_top_domains(self, params=None):
        if params is None:
            params = {}
        action = "DescribeTopDomains"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_top_urls(self, params=None):
        if params is None:
            params = {}
        action = "DescribeTopURLs"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_top_ips(self, params=None):
        if params is None:
            params = {}
        action = "DescribeTopIPs"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_top_referers(self, params=None):
        if params is None:
            params = {}
        action = "DescribeTopReferers"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_domain_pv_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeDomainPVData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_domain_uv_data(self, params=None):
        if params is None:
            params = {}
        action = "DescribeDomainUVData"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_dcdn_region_and_isp(self, params=None):
        if params is None:
            params = {}
        action = "DescribeDcdnRegionAndIsp"
        res = self.get(action, params)
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_statistics_detail(self, params=None):
        if params is None:
            params = {}
        action = "DescribeStatisticsDetail"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_origin_statistics_detail(self, params=None):
        if params is None:
            params = {}
        action = "DescribeOriginStatisticsDetail"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def describe_domain_logs(self, params=None):
        if params is None:
            params = {}
        action = "DescribeDomainLogs"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def create_purge_prefetch_task(self, params=None):
        if params is None:
            params = {}
        action = "CreatePurgePrefetchTask"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def check_purge_prefetch_task(self, params=None):
        if params is None:
            params = {}
        action = "CheckPurgePrefetchTask"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def get_purge_prefetch_task_quota(self, params=None):
        if params is None:
            params = {}
        action = "GetPurgePrefetchTaskQuota"
        res = self.get(action, params)
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json

    def retry_purge_prefetch_task(self, params=None):
        if params is None:
            params = {}
        action = "RetryPurgePrefetchTask"
        res = self.json(action, [], json.dumps(params))
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(res)
        return res_json



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_edit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvod/business/vod_edit.proto\x12\x1eVolcengine.Vod.Models.Business\"0\n\x1fSubmitDirectEditTaskAsyncResult\x12\r\n\x05ReqId\x18\x01 \x01(\t\"\'\n\x15GetDirectEditProgress\x12\x0e\n\x06Result\x18\x01 \x01(\x05\"\x97\x01\n\x13GetDirectEditResult\x12\r\n\x05ReqId\x18\x01 \x01(\t\x12\x11\n\tEditParam\x18\x02 \x01(\x0c\x12\x10\n\x08Priority\x18\x03 \x01(\x05\x12\x13\n\x0b\x43\x61llbackUri\x18\x04 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x05 \x01(\t\x12\x0e\n\x06Status\x18\x06 \x01(\t\x12\x11\n\tOutputVid\x18\x07 \x01(\tB\xc8\x01\n)com.volcengine.service.vod.model.businessB\x07VodEditP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_SUBMITDIRECTEDITTASKASYNCRESULT = DESCRIPTOR.message_types_by_name['SubmitDirectEditTaskAsyncResult']
_GETDIRECTEDITPROGRESS = DESCRIPTOR.message_types_by_name['GetDirectEditProgress']
_GETDIRECTEDITRESULT = DESCRIPTOR.message_types_by_name['GetDirectEditResult']
SubmitDirectEditTaskAsyncResult = _reflection.GeneratedProtocolMessageType('SubmitDirectEditTaskAsyncResult', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITDIRECTEDITTASKASYNCRESULT,
  '__module__' : 'vod.business.vod_edit_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.SubmitDirectEditTaskAsyncResult)
  })
_sym_db.RegisterMessage(SubmitDirectEditTaskAsyncResult)

GetDirectEditProgress = _reflection.GeneratedProtocolMessageType('GetDirectEditProgress', (_message.Message,), {
  'DESCRIPTOR' : _GETDIRECTEDITPROGRESS,
  '__module__' : 'vod.business.vod_edit_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.GetDirectEditProgress)
  })
_sym_db.RegisterMessage(GetDirectEditProgress)

GetDirectEditResult = _reflection.GeneratedProtocolMessageType('GetDirectEditResult', (_message.Message,), {
  'DESCRIPTOR' : _GETDIRECTEDITRESULT,
  '__module__' : 'vod.business.vod_edit_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.GetDirectEditResult)
  })
_sym_db.RegisterMessage(GetDirectEditResult)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\007VodEditP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _SUBMITDIRECTEDITTASKASYNCRESULT._serialized_start=63
  _SUBMITDIRECTEDITTASKASYNCRESULT._serialized_end=111
  _GETDIRECTEDITPROGRESS._serialized_start=113
  _GETDIRECTEDITPROGRESS._serialized_end=152
  _GETDIRECTEDITRESULT._serialized_start=155
  _GETDIRECTEDITRESULT._serialized_end=306
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from __future__ import print_function

import base64
import json

from volcengine.const.Const import *
from volcengine.sms.SmsService import SmsService

if __name__ == '__main__':
    # base64 encode func
    def to_base64_str(file):
        with open(file, 'rb') as fileObj:
            image_data = fileObj.read()
            return base64.b64encode(image_data).decode('utf-8')


    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)
    # cn
    sms_service = SmsService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_scheme("http")
    # sms_service.set_scheme("https")
    # sms_service.set_host('host')
    file_base64_string = to_base64_str("媒体文件路径")
    body = {
        "subAccount": "subAccount",
        "name": "SDK测试",
        "theme": "SDK测试视频短信",
        "signature": "签名",
        "channelType": "CN_VMS",
        "contents": [
            {
                "sourceType": SOURCE_TYPE_TEXT,
                "content": "火山引擎，做企业好的伙伴"
            },
            {
                # choose the midea type
                "sourceType": Source_TYPE_IMAGE_GIF,
                "content": file_base64_string
            }
        ]
    }

    resp = sms_service.apply_vms_template(body)
    print(resp)



# coding:utf-8


class Credentials(object):
    def __init__(self, ak, sk, service, region, session_token=''):
        self.ak = ak
        self.sk = sk
        self.service = service
        self.region = region
        self.session_token = session_token

    def set_ak(self, ak):
        self.ak = ak

    def set_sk(self, sk):
        self.sk = sk

    def set_session_token(self, session_token):
        self.session_token = session_token



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/domain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1alive/business/domain.proto\x12\x1fVolcengine.Live.Models.Business\"\x82\x02\n\nDomainList\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0e\n\x06\x44omain\x18\x02 \x01(\t\x12\x0e\n\x06Status\x18\x03 \x01(\x03\x12\x0c\n\x04Type\x18\x04 \x01(\t\x12\x0e\n\x06Region\x18\x05 \x01(\t\x12\r\n\x05\x43Name\x18\x06 \x01(\t\x12\x12\n\nCnameCheck\x18\x07 \x01(\x03\x12\x13\n\x0b\x44omainCheck\x18\x08 \x01(\x03\x12\x10\n\x08ICPCheck\x18\t \x01(\x03\x12\x12\n\nCreateTime\x18\n \x01(\t\x12\x12\n\nCertDomain\x18\x0b \x01(\t\x12\x0f\n\x07\x43hainID\x18\x0c \x01(\t\x12\x10\n\x08\x43\x65rtName\x18\r \x01(\t\x12\x12\n\nPushDomain\x18\x0e \x01(\t\"`\n\x0e\x44omainListInfo\x12?\n\nDomainList\x18\x01 \x03(\x0b\x32+.Volcengine.Live.Models.Business.DomainList\x12\r\n\x05Total\x18\x02 \x01(\x03\x42\xce\x01\n*com.volcengine.service.live.model.businessB\x06\x44omainP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_DOMAINLIST = DESCRIPTOR.message_types_by_name['DomainList']
_DOMAINLISTINFO = DESCRIPTOR.message_types_by_name['DomainListInfo']
DomainList = _reflection.GeneratedProtocolMessageType('DomainList', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINLIST,
  '__module__' : 'live.business.domain_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.DomainList)
  })
_sym_db.RegisterMessage(DomainList)

DomainListInfo = _reflection.GeneratedProtocolMessageType('DomainListInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINLISTINFO,
  '__module__' : 'live.business.domain_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.DomainListInfo)
  })
_sym_db.RegisterMessage(DomainListInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\006DomainP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _DOMAINLIST._serialized_start=64
  _DOMAINLIST._serialized_end=322
  _DOMAINLISTINFO._serialized_start=324
  _DOMAINLISTINFO._serialized_end=420
# @@protoc_insertion_point(module_scope)
